"""
    Created by prakash at 02/03/22
"""
__author__ = 'Prakash14'


class OS:
    WINDOWS = "Windows"
    WINDOWS_PHONE = "Windows Phone"
    ANDROID = "Android"
    MAC_OS = "Mac Os"
    LINUX = "Linux"
    IOS = "iOS"
    CHROME_OS = "Chrome OS"


class DEVICE_TYPE:
    COMPUTER = "Computer"
    MOBILE = "Mobile"
    SERVER = "Server"
    BOT = "Bot"


class DEVICE_NAME:
    IPHONE = "iPhone"
    IPAD = "iPad"
    MAC = "Mac"
    CHROME_BOOK = "Chrome Book"
    ANDROID = "Android Phone"


MOBILE_DEVICE_CODE_NAME = {
    #  OnePlus Devices
    "AC2003": "OnePlus Nord 5G",
    "EB2101": "OnePlus Nord CE 5G",
    "EB2103": "OnePlus Nord CE 5G",
    "DN2101": "OnePlus Nord 5G",
    "DN2103": "OnePlus Nord 5G",
    "AC2001": "OnePlus Nord",
    "GM1901": "OnePlus 7",
    "A6000": "OnePlus 6",
    "A6010": "OnePlus 6T",
    "A6003": "OnePlus 6",
    "A5010": "OnePlus 5T",
    "A5000": "OnePlus 5",
    "LE2101": "OnePlus 9R",
    "LE2100": "OnePlus 9R",
    "LE2113": "OnePlus 9",
    "LE2111": "OnePlus 9",
    "LE2110": "OnePlus 9",
    "LE2117": "OnePlus 9",
    "LE2121": "OnePlus 9 Pro",
    "LE2125": "OnePlus 9 Pro",
    "LE2123": "OnePlus 9 Pro",
    "LE2120": "OnePlus 9 Pro",
    "LE2127": "OnePlus 9 Pro",
    "GM1911": "OnePlus 7 Pro",
    "GM1913": "OnePlus 7 Pro",
    "GM1917": "OnePlus 7 Pro",
    "GM1910": "OnePlus 7 Pro",
    "GM1915": "OnePlus 7 Pro",
    "HD1901": "OnePlus 7T",
    "HD1903": "OnePlus 7T",
    "HD1900": "OnePlus 7T",
    "HD1907": "OnePlus 7T",
    "HD1905": "OnePlus 7T",
    "HD1911": "OnePlus 7T",
    "KB2001": "OnePlus 8T",
    "KB2000": "OnePlus 8T",
    "KB2003": "OnePlus 8T",
    "KB2005": "OnePlus 8T",
    "IN2013": "OnePlus 8",
    "IN2017": "OnePlus 8",
    "IN2019": "OnePlus 8",
    "IN2010": "OnePlus 8",
    "IN2011": "OnePlus 8",
    "IN2021": "OnePlus 8 Pro",
    "IN2023": "OnePlus 8 Pro",
    "IN2020": "OnePlus 8 Pro",
    "IN2025": "OnePlus 8 Pro",

    # Samsung Devices
    "SM-X900": "Samsung Galaxy Tab S8 Ultra",
    "SM-X906": "Samsung Galaxy Tab S8 Ultra",
    "SM-X800": "Samsung Galaxy Tab S8+",
    "SM-X806": "Samsung Galaxy Tab S8+",
    "SM-X700": "Samsung Galaxy Tab S8",
    "SM-X706": "Samsung Galaxy Tab S8",
    "SM-S908": "Samsung Galaxy S22 Ultra",
    "SM-S906": "Samsung Galaxy S22+",
    "SM-S901": "Samsung Galaxy S22",
    "SM-G990": "Samsung Galaxy S21 FE",
    "SM-A136": "Samsung Galaxy A13 5G",
    "SM-X200": "Samsung Galaxy Tab A8 10.5",
    "SM-X205": "Samsung Galaxy Tab A8 10.5",
    "SM-A032": "Samsung Galaxy A03 Core",
    "SM-E426": "Samsung Galaxy F42 5G",
    "SM-M526": "Samsung Galaxy M52 5G",
    "SM-M225": "Samsung Galaxy M22",
    "SM-M326": "Samsung Galaxy M32 5G",
    "SM-A037": "Samsung Galaxy A03s",
    "SM-A528": "Samsung Galaxy A52s 5G",
    "SM-F926B": "Samsung Galaxy Z Fold3 5G",
    "SM-F711B": "Samsung Galaxy Z Flip3 5G",
    "SM-E225": "Samsung Galaxy F22",
    "SM-M325": "Samsung Galaxy M32",
    "SM-A226": "Samsung Galaxy A22 5G",
    "SM-A225": "Samsung Galaxy A22",
    "SM-T730": "Samsung Galaxy Tab S7 FE",
    "SM-T736B": "Samsung Galaxy Tab S7 FE",
    "SM-T220": "Samsung Galaxy Tab A7 Lite",
    "SM-T225": "Samsung Galaxy Tab A7 Lite",
    "SM-E526": "Samsung Galaxy F52 5G",
    "SM-M426": "Samsung Galaxy M42 5G",
    "SM-E025": "Samsung Galaxy F02s",
    "SM-F127": "Samsung Galaxy F12",
    "SM-A725": "Samsung Galaxy A72",
    "SM-A526": "Samsung Galaxy A52 5G",
    "SM-A525": "Samsung Galaxy A52",
    "SM-A325": "Samsung Galaxy A32",
    "SM-M625": "Samsung Galaxy M62",
    "SM-E625": "Samsung Galaxy F62",
    "SM-M127": "Samsung Galaxy M12",
    "SM-M022": "Samsung Galaxy M02",
    "SM-A022": "Samsung Galaxy A02",
    "SM-G991": "Samsung Galaxy S21",
    "SM-G996": "Samsung Galaxy S21+",
    "SM-G998": "Samsung Galaxy S21 Ultra",
    "SM-A326": "Samsung Galaxy A32 5G",
    "SM-M025": "Samsung Galaxy M02s",
    "SM-A025": "Samsung Galaxy A02s",
    "SM-A125": "Samsung Galaxy A12",
    "SM-M217": "Samsung Galaxy M21s",
    "SM-A426": "Samsung Galaxy A42 5G",
    "SM-F415": "Samsung Galaxy F41",
    "SM-G780": "Samsung Galaxy S20 FE",
    "SM-G781": "Samsung Galaxy S20 FE",
    "SM-F916B": "Samsung Galaxy Z Fold2 5G",
    "SM-M515": "Samsung Galaxy M51",
    "SM-N980": "Samsung Galaxy Note 20",
    "SM-N981": "Samsung Galaxy Note 20",
    "SM-N985": "Samsung Galaxy Note 20 Ultra",
    "SM-N986": "Samsung Galaxy Note 20 Ultra",
    "SM-F707": "Samsung Galaxy Z Flip 5G",
    "SM-T870": "Samsung Galaxy Tab S7",
    "SM-T875": "Samsung Galaxy Tab S7",
    "SM-T876B": "Samsung Galaxy Tab S7",
    "SM-T970": "Samsung Galaxy Tab S7+",
    "SM-T976B": "Samsung Galaxy Tab S7+",
    "SM-M317": "Samsung Galaxy M31s",
    "SM-A013": "Samsung Galaxy A01 Core",
    "SM-M017": "Samsung Galaxy M01s",
    "SM-M015": "Samsung Galaxy M01",
    "SM-A217": "Samsung Galaxy A21s",
    "SM-A716F": "Samsung Galaxy A71 5G",
    "SM-A516F": "Samsung Galaxy A51 5G",
    "SM-A215": "Samsung Galaxy A21",
    "SM-P610N": "Samsung Galaxy Tab S6 Lite",
    "SM-P615": "Samsung Galaxy Tab S6 Lite",
    "SM-G980": "Samsung Galaxy S20",
    "SM-G981": "Samsung Galaxy S20",
    "SM-G985": "Samsung Galaxy S20+",
    "SM-G986": "Samsung Galaxy S20+",
    "SM-G988": "Samsung Galaxy S20 Ultra",
    "SM-M115": "Samsung Galaxy M11",
    "SM-M115F": "Samsung Galaxy M11",
    "SM-A315": "Samsung Galaxy A31",
    "SM-A415": "Samsung Galaxy A41",
    "SM-M215": "Samsung Galaxy M21",
    "SM-A115": "Samsung Galaxy A11",
    "SM-M315": "Samsung Galaxy M31",
    "SM-F700": "Samsung Galaxy Z Flip",
    "SM-T866N": "Samsung Galaxy Tab S6 5G",
    "SM-G715F": "Samsung Galaxy Xcover Pro",
    "SM-N770F": "Samsung Galaxy Note 10 Lite",
    "SM-G770F": "Samsung Galaxy S10 Lite",
    "SM-A015": "Samsung Galaxy A01",
    "SM-A715": "Samsung Galaxy A71",
    "SM-A515": "Samsung Galaxy A51",
    "SM-M307": "Samsung Galaxy M30s",
    "SM-A207": "Samsung Galaxy A20s",
    "SM-M107": "Samsung Galaxy M10s",
    "SM-A707": "Samsung Galaxy A70s",
    "SM-A507": "Samsung Galaxy A50s",
    "SM-A307": "Samsung Galaxy A30s",
    "SM-A908": "Samsung Galaxy A90 5G",
    "SM-F900": "Samsung Galaxy Z Fold",
    "SM-F907": "Samsung Galaxy Z Fold",
    "SM-A107": "Samsung Galaxy A10s",
    "SM-A102": "Samsung Galaxy A10e",
    "SM-N970": "Samsung Galaxy Note 10",
    "SM-N971": "Samsung Galaxy Note 10",
    "SM-N975F": "Samsung Galaxy Note 10+",
    "SM-N976": "Samsung Galaxy Note 10+",
    "SM-M405": "Samsung Galaxy M40",
    "SM-G977": "Samsung Galaxy S10 5G",
    "SM-T920": "Samsung Galaxy View 2",
    "SM-T927": "Samsung Galaxy View 2",
    "SM-T927A": "Samsung Galaxy View 2",
    "SM-A606": "Samsung Galaxy A60",
    "SM-A805": "Samsung Galaxy A80",
    "SM-A705": "Samsung Galaxy A70",
    "SM-A405": "Samsung Galaxy A40",
    "SM-A205": "Samsung Galaxy A20",
    "SM-A202": "Samsung Galaxy A20e",
    "SM-A260": "Samsung Galaxy A2 Core",
    "SM-G975": "Samsung Galaxy S10+",
    "SM-G973": "Samsung Galaxy S10",
    "SM-G970": "Samsung Galaxy S10e",
    "SM-A505": "Samsung Galaxy A50",
    "SM-A305": "Samsung Galaxy A30",
    "SM-A105": "Samsung Galaxy A10",
    "SM-T720": "Samsung Galaxy Tab S5e",
    "SM-T725": "Samsung Galaxy Tab S5e",
    "SM-T510": "Samsung Galaxy Tab A 10.1 (2019)",
    "SM-T515": "Samsung Galaxy Tab A 10.1 (2019)",
    "SM-M305": "Samsung Galaxy M30",
    "SM-M105": "Samsung Galaxy M10",
    "SM-M205": "Samsung Galaxy M20",
    "SM-G887": "Samsung Galaxy A8s",
    "SM-G6200": "Samsung Galaxy A6s",
    "SM-A920": "Samsung Galaxy A9 (2018)",
    "SM-A750": "Samsung Galaxy A7 (2018)",
    "SM-J415": "Samsung Galaxy J4+",
    "SM-J610": "Samsung Galaxy J6+",
    "SM-N960": "Samsung Galaxy Note 9",
    "SM-T590": "Samsung Galaxy Tab A 10.5 (2018)",
    "; SM-T595": "Samsung Galaxy Tab A 10.5 (2018)",
    "SM-T830": "Samsung Galaxy Tab S4",
    "; SM-T835": "Samsung Galaxy Tab S4",
    "SM-J800": "Samsung Galaxy J8 (2018)",
    "SM-J600G": "Samsung Galaxy On6",
    "SM-G8850": "Samsung Galaxy A8 Star[16]",
    "SM-J737": "Samsung Galaxy J7 (2018)",
    "SM-A600": "Samsung Galaxy A6 (2018)",
    "SM-A605": "Samsung Galaxy A6+ (2018)",
    "SM-J400": "Samsung Galaxy J4 (2018)",
    "SM-J600": "Samsung Galaxy J6 (2018)",
    "SM-J720": "Samsung Galaxy J3 Duo",
    "SM-G611": "Samsung Galaxy J4 Prime 2 Samsung Galaxy J7 (2018)",
    "SM-G960": "Samsung Galaxy S9",
    "SM-G965": "Samsung Galaxy S9+",
    "SM-J250": "Samsung Galaxy J4 Pro (2018)",
    "SM-A530": "Samsung Galaxy A5 (2018)[17]",
    "SM-A730": "Samsung Galaxy A5+ (2018)",
    "SM-J200G": "Samsung Galaxy J2",
    "SM-T380": "Samsung Galaxy Tab A 8.0 (2017)",
    "SM-T385": "Samsung Galaxy Tab A 8.0 (2017)",
    "SM-C710": "Samsung Galaxy C8 / C7 (2017)Samsung Galaxy J7+",
    "SM-C8000": "Samsung Galaxy C8 / C7 (2017)Samsung Galaxy J7+",
    "SM-N950": "Samsung Galaxy Note 8",
    "SM-G892": "Samsung Galaxy S8 Active",
    "SM-N935": "Samsung Galaxy Note Fan Edition (FE)",
    "SM-J727": "Samsung Galaxy J3 (2017)",
    "SM-J730x": "Samsung Galaxy J3 (2017)",
    "SM-J530": "Samsung Galaxy J5 (2017)",
    "SM-J530Y": "Samsung Galaxy J5 (2017)",
    "SM-J327": "Samsung Galaxy J7 (2017)",
    "SM-J330x": "Samsung Galaxy J7 (2017)",
    "SM-J730": "Samsung Galaxy J7 Pro (2017)",
    "SM-G615": "Samsung Galaxy J7 Max",
    "SM-G390": "Samsung Galaxy Xcover 4",
    "SM-G950": "Samsung Galaxy S8",
    "SM-G955": "Samsung Galaxy S8+",
    "SM-C5010": "Samsung Galaxy C5 Pro",
    "SM-T820": "Samsung Galaxy Tab S3",
    "SM-T825": "Samsung Galaxy Tab S3",
    "SM-A720": "Samsung Galaxy A7 (2017)",
    "SM-A520": "Samsung Galaxy A5 (2017)",
    "SM-A320": "Samsung Galaxy A3 (2017)",
    "SM-C7010": "Samsung Galaxy C5 Pro",
    "SM-J106F": "Samsung Galaxy J1 mini Prime/Galaxy V2 (Indonesia)",
    "SM-G532F": "Samsung Galaxy J2 Prime",
    "SM-G532M": "Samsung Galaxy J2 Prime",
    "SM-G532G": "Samsung Galaxy J2 Prime",
    "SM-C900F": "Samsung Galaxy C9 Pro",
    "SM-A810": "Samsung Galaxy A8 (2016)",
    "SM-G570": "Samsung Galaxy On5 (2016)",
    "SM-G610": "Samsung Galaxy On5 (2016)",
    "SM-J710": "Samsung Galaxy On7 (2016)",
    "SM-G610F": "Samsung Galaxy J7 Prime",
    "SM-G610M": "Samsung Galaxy J7 Prime",
    "SM-N930": "Samsung Galaxy Note 7",
    "SM-G570F": "Samsung Galaxy J2 Prime",
    "SM-G570M": "Samsung Galaxy J2 Prime",
    "SM-G891A": "Samsung Galaxy S7 Active",
    "SM-J310F": "Samsung Galaxy J3 Pro",
    "SM-T585": "Samsung Galaxy Tab A 10.1 (2016)",
    "SM-C5000": "Samsung Galaxy C5",
    "SM-C7000": "Samsung Galaxy C7",
    "SM-J5109": "Samsung Galaxy J5 (2016)",
    "SM-J510F": "Samsung Galaxy J5 (2016)",
    "SM-J510FN": "Samsung Galaxy J5 (2016)",
    "SM-J510H": "Samsung Galaxy J5 (2016)",
    "SM-J510G": "Samsung Galaxy J5 (2016)",
    "SM-J510MN": "Samsung Galaxy J5 (2016)",
    "SM-J510Y": "Samsung Galaxy J5 (2016)",
    "SM-J5108": "Samsung Galaxy J5 (2016)",
    "SM-J510K": "Samsung Galaxy J5 (2016)",
    "SM-J510L": "Samsung Galaxy J5 (2016)",
    "SM-J510S": "Samsung Galaxy J5 (2016)",
    "SM-J510UN": "Samsung Galaxy J5 (2016)",
    "SM-J7109": "Samsung Galaxy J7 (2016)",
    "SM-J710F": "Samsung Galaxy J7 (2016)",
    "SM-J710FN": "Samsung Galaxy J7 (2016)",
    "SM-J710H": "Samsung Galaxy J7 (2016)",
    "SM-J710MN": "Samsung Galaxy J7 (2016)",
    "SM-J710FQ": "Samsung Galaxy J7 (2016)",
    "SM-J710K": "Samsung Galaxy J7 (2016)",
    "SM-J710GN": "Samsung Galaxy J7 (2016)",
    "SM-J3109x": "Samsung Galaxy J3 (2016)",
    "SM-J320F": "Samsung Galaxy J3 (2016)",
    "SM-J320G": "Samsung Galaxy J3 (2016)",
    "SM-J320P": "Samsung Galaxy J3 (2016)",
    "SM-J320M": "Samsung Galaxy J3 (2016)",
    "SM-T280": "Samsung Galaxy Tab A6",
    "SM-T285": "Samsung Galaxy Tab A6",
    "SM-A9100": "Samsung Galaxy A9 Pro (2016)",
    "SM-A910F": "Samsung Galaxy A9 Pro (2016)",
    "SM-J105B": "Samsung Galaxy J1 Mini",
    "SM-J105DS": "Samsung Galaxy J1 Mini",
    "SM-J105F": "Samsung Galaxy J1 Mini",
    "SM-G935F": "Samsung Galaxy S7 Edge",
    "SM-G935FD": "Samsung Galaxy S7 Edge",
    "SM-G9350": "Samsung Galaxy S7 Edge",
    "SM-G935A": "Samsung Galaxy S7 Edge",
    "SM-G935V": "Samsung Galaxy S7 Edge",
    "SM-G935U": "Samsung Galaxy S7 Edge",
    "SM-G935S": "Samsung Galaxy S7 Edge",
    "SM-G935K": "Samsung Galaxy S7 Edge",
    "SM-G935W8": "Samsung Galaxy S7 Edge",
    "SC-02H": "Samsung Galaxy S7 Edge",
    "SM-G930F": "Samsung Galaxy S7",
    "SM-G930FD": "Samsung Galaxy S7",
    "SM-G9300": "Samsung Galaxy S7",
    "SM-G930A": "Samsung Galaxy S7",
    "SM-G930V": "Samsung Galaxy S7",
    "SM-G930AZ": "Samsung Galaxy S7",
    "SM-G930S": "Samsung Galaxy S7",
    "SM-G930K": "Samsung Galaxy S7",
    "SM-G930W8": "Samsung Galaxy S7",
    "SM-J120F": "Samsung Galaxy J1 (2016)",
    "SM-J120M": "Samsung Galaxy J1 (2016)",
    "SM-A9000": "Samsung Galaxy A9 (2016)",
    "SM-A7100": "Samsung Galaxy A7 (2016)",
    "SM-A710F": "Samsung Galaxy A7 (2016)",
    "SM-A710FD": "Samsung Galaxy A7 (2016)",
    "SM-A710M": "Samsung Galaxy A7 (2016)",
    "SM-A710Y": "Samsung Galaxy A7 (2016)",
    "SM-A5100": "Samsung Galaxy A5 (2016)",
    "SM-A510F": "Samsung Galaxy A5 (2016)",
    "SM-A510FD": "Samsung Galaxy A5 (2016)",
    "SM-A510M": "Samsung Galaxy A5 (2016)",
    "SM-A510Y": "Samsung Galaxy A5 (2016)",
    "SM-A310F": "Samsung Galaxy A3 (2016)",
    "SM-A310M": "Samsung Galaxy A3 (2016)",
    "SM-T670": "Samsung Galaxy View",
    "SC-01H": "Samsung Galaxy Active Neo",
    "SM-J200F": "Samsung Galaxy J2",
    "SM-J200Y": "Samsung Galaxy J2",
    "SM-J200H": "Samsung Galaxy J2",
    "SM-J200M": "Samsung Galaxy J2",
    "SM-G928A": "Samsung Galaxy S6 Edge+",
    "SM-G928AZ": "Samsung Galaxy S6 Edge+",
    "SM-G928D": "Samsung Galaxy S6 Edge+",
    "SM-G928F": "Samsung Galaxy S6 Edge+",
    "SM-G928FD": "Samsung Galaxy S6 Edge+",
    "SM-G928I": "Samsung Galaxy S6 Edge+",
    "SM-G928K": "Samsung Galaxy S6 Edge+",
    "SM-G928L": "Samsung Galaxy S6 Edge+",
    "SM-G928P": "Samsung Galaxy S6 Edge+",
    "SM-G928PZ": "Samsung Galaxy S6 Edge+",
    "SM-G928R4": "Samsung Galaxy S6 Edge+",
    "SM-G928R7": "Samsung Galaxy S6 Edge+",
    "SM-G928S": "Samsung Galaxy S6 Edge+",
    "SM-G928T": "Samsung Galaxy S6 Edge+",
    "SM-G928T1": "Samsung Galaxy S6 Edge+",
    "SM-G928TR": "Samsung Galaxy S6 Edge+",
    "SM-G928V": "Samsung Galaxy S6 Edge+",
    "SM-G9280": "Samsung Galaxy S6 Edge+",
    "SM-G9288": "Samsung Galaxy S6 Edge+",
    "SM-G9289": "Samsung Galaxy S6 Edge+",
    "SM-A8000": "Samsung Galaxy A8",
    "SM-A800F": "Samsung Galaxy A8",
    "SM-A800I": "Samsung Galaxy A8",
    "SM-A800S": "Samsung Galaxy A8",
    "SM-A800Y": "Samsung Galaxy A8",
    "SM-N9200": "Samsung Galaxy Note 5",
    "SM-N920C": "Samsung Galaxy Note 5",
    "SM-N920T": "Samsung Galaxy Note 5",
    "SM-N920A": "Samsung Galaxy Note 5",
    "SM-N920I": "Samsung Galaxy Note 5",
    "SM-N9208": "Samsung Galaxy Note 5",
    "SM-G903F": "Samsung Galaxy S5 Neo",
    "SM-G903W": "Samsung Galaxy S5 Neo",
    "SM-G318H": "Samsung Galaxy Trend 2 Lite",
    "SM-G890A": "Samsung Galaxy S6 Active",
    "SM-J500F": "Samsung Galaxy J5",
    "SM-J500H": "Samsung Galaxy J5",
    "SM-J500M": "Samsung Galaxy J5",
    "SM-J500G": "Samsung Galaxy J5",
    "SM-J700F": "Samsung Galaxy J7",
    "SM-J700H": "Samsung Galaxy J7",
    "SM-J700M": "Samsung Galaxy J7",
    "SM-J700T": "Samsung Galaxy J7",
    "SM-J700P": "Samsung Galaxy J7",
    "SM-G925A": "Samsung Galaxy S6 Edge",
    "SM-G925AZ": "Samsung Galaxy S6 Edge",
    "SM-G925F": "Samsung Galaxy S6 Edge",
    "SM-G925I": "Samsung Galaxy S6 Edge",
    "SM-G925K": "Samsung Galaxy S6 Edge",
    "SM-G925L": "Samsung Galaxy S6 Edge",
    "SM-G925P": "Samsung Galaxy S6 Edge",
    "SM-G925PZ": "Samsung Galaxy S6 Edge",
    "SM-G925R4": "Samsung Galaxy S6 Edge",
    "SM-G925R7": "Samsung Galaxy S6 Edge",
    "SM-G925S": "Samsung Galaxy S6 Edge",
    "SM-G925T": "Samsung Galaxy S6 Edge",
    "SM-G925T1": "Samsung Galaxy S6 Edge",
    "SM-G925TR": "Samsung Galaxy S6 Edge",
    "SM-G925V": "Samsung Galaxy S6 Edge",
    "SM-G9250": "Samsung Galaxy S6 Edge",
    "SM-G9258": "Samsung Galaxy S6 Edge",
    "SM-G9259": "Samsung Galaxy S6 Edge",
    "SM-G920A": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920AZ": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920D": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920F": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920FD": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920I": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920K": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920L": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920P": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920PZ": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920R4": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920R7": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920S": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920T": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920T1": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920TR": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G920V": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G9200": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G9208": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-G9209": "Samsung Galaxy S6Samsung Galaxy Gear 2",
    "SM-J100H": "Samsung Galaxy J1",
    "SM-J100F": "Samsung Galaxy J1",
    "SM-E500H": "Samsung Galaxy E5",
    "SM-E500F": "Samsung Galaxy E5",
    "SM-A700F": "Samsung Galaxy A7",
    "SM-A700FD": "Samsung Galaxy A7",
    "SM-A700FQ": "Samsung Galaxy A7",
    "SM-A700H": "Samsung Galaxy A7",
    "SM-A700K": "Samsung Galaxy A7",
    "SM-A700L": "Samsung Galaxy A7",
    "SM-A700M": "Samsung Galaxy A7",
    "SM-A700S": "Samsung Galaxy A7",
    "SM-A700X": "Samsung Galaxy A7",
    "SM-A700YD": "Samsung Galaxy A7",
    "SM-A700YZ": "Samsung Galaxy A7",
    "SM-A7000": "Samsung Galaxy A7",
    "SM-A7009": "Samsung Galaxy A7",
    "SM-A7009W": "Samsung Galaxy A7",
    "SM-E700H": "Samsung Galaxy E7",
    "SM-A500F": "Samsung Galaxy A5 (2015)",
    "SM-A500F1": "Samsung Galaxy A5 (2015)",
    "SM-A500FQ": "Samsung Galaxy A5 (2015)",
    "SM-A500FU": "Samsung Galaxy A5 (2015)",
    "SM-A500G": "Samsung Galaxy A5 (2015)",
    "SM-A500H": "Samsung Galaxy A5 (2015)",
    "SM-A500HQ": "Samsung Galaxy A5 (2015)",
    "SM-A500K": "Samsung Galaxy A5 (2015)",
    "SM-A500L": "Samsung Galaxy A5 (2015)",
    "SM-A500M": "Samsung Galaxy A5 (2015)",
    "SM-A500S": "Samsung Galaxy A5 (2015)",
    "SM-A500X": "Samsung Galaxy A5 (2015)",
    "SM-A500XZ": "Samsung Galaxy A5 (2015)",
    "SM-A500Y": "Samsung Galaxy A5 (2015)",
    "SM-A500YZ": "Samsung Galaxy A5 (2015)",
    "SM-A5000": "Samsung Galaxy A5 (2015)",
    "SM-A5009": "Samsung Galaxy A5 (2015)",
    "SM-A300F": "Samsung Galaxy A3 (2015)",
    "SM-A300FU": "Samsung Galaxy A3 (2015)",
    "SM-A300G": "Samsung Galaxy A3 (2015)",
    "SM-A300H": "Samsung Galaxy A3 (2015)",
    "SM-A300HQ": "Samsung Galaxy A3 (2015)",
    "SM-A300M": "Samsung Galaxy A3 (2015)",
    "SM-A300X": "Samsung Galaxy A3 (2015)",
    "SM-A300XU": "Samsung Galaxy A3 (2015)",
    "SM-A300XZ": "Samsung Galaxy A3 (2015)",
    "SM-A300Y": "Samsung Galaxy A3 (2015)",
    "SM-A300YZ": "Samsung Galaxy A3 (2015)",
    "SM-A3000": "Samsung Galaxy A3 (2015)",
    "SM-A3009": "Samsung Galaxy A3 (2015)",
    "SM-G360BT": "Samsung Galaxy Core Prime",
    "SM-G360H": "Samsung Galaxy Core Prime",
    "SM-N915G": "Samsung Galaxy Note Edge",
    "SM-N9150": "Samsung Galaxy Note Edge",
    "SM-N910G": "Samsung Galaxy Note 4",
    "SM-G130H": "Samsung Galaxy Young 2",
    "SM-G850F": "Samsung Galaxy Alpha",
    "SM-G850FQ": "Samsung Galaxy Alpha",
    "SM-G850K": "Samsung Galaxy Alpha",
    "SM-G850L": "Samsung Galaxy Alpha",
    "SM-G850M": "Samsung Galaxy Alpha",
    "SM-G850S": "Samsung Galaxy Alpha",
    "SM-G850W": "Samsung Galaxy Alpha",
    "SM-G850Y": "Samsung Galaxy Alpha",
    "SM-G530BT": "Samsung Galaxy Grand Prime",
    "SM-G530F": "Samsung Galaxy Grand Prime",
    "SM-G530FQ": "Samsung Galaxy Grand Prime",
    "SM-G530FZ": "Samsung Galaxy Grand Prime",
    "SM-G530H": "Samsung Galaxy Grand Prime",
    "SM-G530M": "Samsung Galaxy Grand Prime",
    "SM-G530MU": "Samsung Galaxy Grand Prime",
    "SM-G530P": "Samsung Galaxy Grand Prime",
    "SM-G530R4": "Samsung Galaxy Grand Prime",
    "SM-G530R7": "Samsung Galaxy Grand Prime",
    "SM-G530T": "Samsung Galaxy Grand Prime",
    "SM-G530W": "Samsung Galaxy Grand Prime",
    "SM-G530Y": "Samsung Galaxy Grand Prime",
    "SM-G5306W": "Samsung Galaxy Grand Prime",
    "SM-G5308W": "Samsung Galaxy Grand Prime",
    "SM-G5309W": "Samsung Galaxy Grand Prime",
    "SM-G110B": "Samsung Galaxy Pocket 2",
    "SM-G750F": "Samsung Galaxy Mega 2",
    "SM-G350E": "Samsung Galaxy Star 2 Plus",
    "SM-G313F": "Samsung Galaxy Ace 4",
    "SM-G355H": "Samsung Galaxy Core 2",
    "GT-S5500": "Samsung Galaxy S5 Mini",
    "GT-S5430": "Samsung Galaxy S5 Mini",
    "SM-T800": "Samsung Galaxy Tab S 10.5",
    "SM-T805": "Samsung Galaxy Tab S 10.5",
    "SM-T807": "Samsung Galaxy Tab S 10.5",
    "SM-T807P": "Samsung Galaxy Tab S 10.5",
    "SM-T807V": "Samsung Galaxy Tab S 10.5",
    "SM-G386F": "Samsung Galaxy Core",
    "SM-C115": "Samsung Galaxy K Zoom",
    "SM-G310": "Samsung Galaxy Ace Style",
    "SM-G900": "Samsung Galaxy S5",
    "SM-G900FD": "Samsung Galaxy S5",
    "GT-I9300I": "Samsung Galaxy S3 Neo",
    "GT-I9301I": "Samsung Galaxy S3 Neo",
    "GT-I9303I": "Samsung Galaxy S3 Neo",
    "SM-N7500": "Samsung Galaxy Note 3 Neo",
    "SM-N7502": "Samsung Galaxy Note 3 Neo",
    "SM-N7505": "Samsung Galaxy Note 3 Neo",
    "SM-G7102": "Samsung Galaxy Grand 2 (SM-G7100)",
    "GT-S7262": "Samsung Galaxy Star Pro (GT-S7260)",
    "GT-S7392": "Samsung Galaxy Trend Lite (GT-S7390)",
    "SM-G3502": "Samsung Galaxy Core Plus (SM-G3500)",
    "SM-N9000": "Samsung Galaxy Note 3",
    "SM-N9002": "Samsung Galaxy Note 3",
    "SM-N9005": "Samsung Galaxy Note 3",
    "SM-V700": "Samsung Galaxy Gear",
    "GT-S7272": "Samsung Galaxy Ace 3 (GT-S7270)[20]",
    "GT-S7275": "Samsung Galaxy Ace 3 (GT-S7270)[20]",
    "GT-S5312": "Samsung Galaxy Pocket Neo (GT-S5310)",
    "GT-S5282": "Samsung Galaxy Star (GT-S5280)",
    "GT-S5283": "Samsung Galaxy Star (GT-S5280)",
    "GT-i8262D": "Samsung Galaxy Core (GT-S8262)",
    "Galaxy Grand Quattro": "Samsung Galaxy Win (GT-I8550)",
    "GT-I9150": "Samsung Galaxy Mega",
    "GT-I9152": "Samsung Galaxy Mega",
    "GT-I9200": "Samsung Galaxy Mega",
    "GT-I9205": "Samsung Galaxy Mega",
    "GT-S6810P": "Samsung Galaxy Fame (GT-S6810)",
    "GT-I9505": "Samsung Galaxy S4 (GT-I9500)",
    "GT-I9506": "Samsung Galaxy S4 (GT-I9500)",
    "GT-S6312": "Samsung Galaxy Young (GT-S6310)",
    "GT-I9082": "Samsung Galaxy Grand (GT-I9080)",
    "SGH-I437": "Samsung Galaxy Express",
    "GT-N7100": "Samsung Galaxy Note II",
    "GT-N7102": "Samsung Galaxy Note II",
    "GT-N7105": "Samsung Galaxy Note II",
    "GT-B5512": "Samsung Galaxy Y Pro DUOS (GT-B5510)[33]",
    "GT-I5700": "Samsung Galaxy Spica[67]",
    "GT-I7500": "Samsung Galaxy[68]",
    # OPPO Devices
    'CPH1911': 'OPPO F11',
    'CPH1909': 'Oppo A5s',
    'CPH1913': 'OPPO F11',
    'CPH1931': 'OPPO A5 2020',
    'CPH1933': 'OPPO A5 2020',
    'CPH1937': 'OPPO A9 2020',
    'CPH1969': 'OPPO F11 Pro',
    'CPH1989': 'OPPO Reno2 F',
    'CPH2001': 'OPPO F15',
    'CPH2015': 'OPPO A31',
    'CPH2023': 'OPPO Find X2',
    'CPH2035': 'OPPO Reno3 Pro',
    'CPH2061': 'OPPO A52',
    'CPH2071': 'OPPO A11k',
    'CPH2077': 'OPPO A12',
    'CPH2083': 'OPPO A11k',
    'CPH2109': 'OPPO Reno4 Pro',
    'CPH2127': 'OPPO A53',
    'CPH2137': 'OPPO A33',
    'CPH2179': 'OPPO A15s',
    'CPH2185': 'OPPO A15',
    'CPH2201': 'OPPO Reno5 Pro 5G',
    'CPH2213': 'OPPO F19 Pro+',
    'CPH2219': 'OPPO F19',
    'CPH2239': 'OPPO A54',
    'CPH2249': ' OPPO Reno6 Pro 5G',
    'CPH2251': 'OPPO Reno6 5G',
    'CPH2263': 'OPPO A74 5G',
    'CPH2269': 'OPPO A16',
    'CPH2285': 'OPPO F19 Pro',
    'CPH2293': 'OPPO Reno7 Pro 5G',
    'CPH2321': 'OPPO A53s 5G',
    'CPH2325': 'OPPO A55',
    'CPH2349': 'OPPO A16k',
    'CPH2371': 'OPPO Reno7 5G',
    'Not Available': 'OPPO F17',

    # Huawei/ Honor Devices
    "YAL-TL00": "Honor 20",
    "YAL-L71": "Huawei nova 5T",
    "YAL-L61": "Huawei nova 5T",
    "YAL-L41": "Honor 20 Pro",
    "YAL-L21": "Huawei nova 5T",
    "YAL-AL50": "Honor 20S",
    "YAL-AL10": "Honor 20 Pro",
    "YAL-AL00I": "Honor 20",
    "YAL-AL00": "Honor 20",
    "Y635-TL00": "Huawei Y635",
    "Y635-L21": "Huawei Y635",
    "Y635-L03": "Huawei Y635",
    "Y635-L02": "Huawei Y635",
    "Y635-L01": "Huawei Y635",
    "Y635-CL00": "Huawei Y635",
    "Y625-U51": "Huawei Y625",
    "Y625-U43": "Huawei Y625",
    "Y625-U32": "Huawei Y625",
    "Y625-U21": "Huawei Y625",
    "Y625-U13": "Huawei Y625",
    "Y610-U00": "Huawei Y610-U00",
    "Y600-U40": "Huawei Ascend Y600",
    "Y600-U351": "Huawei Ascend Y600",
    "Y600-U20": "Huawei Ascend Y600",
    "Y600-U151": "Huawei Ascend Y600",
    "Y600-U00": "Huawei Ascend Y600",
    "Y560-U23": "Huawei Y560",
    "Y560-U02": "Huawei Y560",
    "Y560-L23": "Huawei Y560",
    "Y560-L03": "Huawei Y560",
    "Y560-L02": "Huawei Y560",
    "Y560-L01": "Huawei Y560",
    "Y550-L03": "Huawei Ascend Y550",
    "Y550-L02": "Huawei Ascend Y550",
    "Y550-L01": "Huawei Ascend Y550",
    "Y541-U02": "Huawei Y541",
    "Y540-U01": "Huawei Ascend Y540",
    "Y538": "Huawei Union Y538",
    "Y536-A1": "Huawei Y536",
    "Y530-U051": "Huawei Y530",
    "Y530-U00": "Huawei Y530",
    "Y520-U33": "Huawei Ascend Y520",
    "Y520-U22": "Huawei Ascend Y520",
    "Y520-U12": "Huawei Ascend Y520",
    "Y520-U03": "Huawei Ascend Y520",
    "Y511-U30": "Huawei Ascend Y511",
    "Y511-U251": "Huawei Ascend Y511",
    "Y511-U10": "Huawei Ascend Y511",
    "Y511-U00": "Huawei Y511",
    "Y360-U93": "Huawei Y3 lite",
    "Y360-U82": "Huawei Y3 Lite",
    "Y360-U61": "Huawei Y360",
    "Y360-U31": "Huawei Y360",
    "Y360-U23": "Huawei Y360",
    "Y360-U03": "Huawei Y360",
    "Y340-U081": "Huawei Y340",
    "Y336-U02": "Huawei Y336",
    "Y330-U17": "Huawei Ascend Y330",
    "Y330-U15": "Huawei Ascend Y330",
    "Y330-U11": "Huawei Ascend Y330",
    "Y330-U07": "Huawei Ascend Y330",
    "Y330-U05": "Huawei Ascend Y330",
    "Y330-U01": "Huawei Ascend Y330",
    "Y321-U051": "Huawei Ascend Y321",
    "Y320-U351": "Huawei Ascend Y320",
    "Y320-U30": "Huawei Ascend Y320",
    "Y320-U151": "Huawei Ascend Y320",
    "Y320-U10": "Huawei Ascend Y320",
    "Y320-U01": "Huawei Ascend Y320",
    "Y300-0151": "Huawei Ascend Y300",
    "Y300-0100": "Huawei Ascend Y300",
    "Y300-0000": "Huawei Ascend Y300",
    "Y221-U33": "Huawei Ascend Y221",
    "Y221-U22": "Huawei Ascend Y221",
    "Y221-U12": "Huawei Ascend Y221",
    "Y221-U03": "Huawei Ascend Y221",
    "Y220-U10": "Huawei Ascend Y220",
    "Y220-U05": "Huawei Ascend Y220",
    "Y220-U00": "Huawei Ascend Y220",
    "Y210-0200": "Huawei Ascend Y210",
    "Y210-0151": "Huawei Ascend Y210",
    "WLZ-AN00": "Huawei nova 6 5G",
    "WLZ-AL10": "Huawei nova 6",
    "WKG-TN00": "Huawei Enjoy 20 SE",
    "WKG-L29": "Huawei Enjoy 20 5G",
    "WKG-L09": "Huawei Enjoy 20 5G",
    "WKG-AN00": "Huawei Enjoy 20 5G",
    "WAS-TL10": "Huawei P10 Lite Dual",
    "WAS-LX3": "Huawei P10 Lite",
    "WAS-LX2": "Huawei P10 Lite",
    "WAS-LX1": "Huawei P10 Lite",
    "WAS-L23": "Huawei P10 Lite",
    "WAS-L22J": "Huawei WAS-L22J",
    "WAS-L22": "Huawei P10 Lite",
    "WAS-L21": "Huawei P10 Lite",
    "WAS-L03": "Huawei P10 Lite",
    "WAS-L02": "Huawei P10 Lite",
    "WAS-L01": "Huawei P10 Lite",
    "WAS-AL00": "Huawei Nova Youth Dual",
    "Warsaw-LX2": "Huawei P10",
    "Warsaw-LX1": "Huawei Warsaw-LX1",
    "Warsaw-L23": "Huawei P10",
    "Warsaw-L22": "Huawei P10",
    "Warsaw-L21": "Huawei P10",
    "Warsaw-L03": "Huawei Warsaw-L03",
    "Warsaw-L02": "Huawei Warsaw-L02",
    "W1-U00": "Huawei W1",
    "VTR-TL00": "Huawei P10",
    "VTR-L29": "Huawei P10",
    "VTR-L09": "Huawei P10",
    "VTR-AL00": "Huawei P10",
    "VRD-W10": "Huawei MediaPad M6 Turbo 8.4",
    "VRD-W09": "Huawei MediaPad M6 Turbo 8.4",
    "VRD-AL10": "Huawei MediaPad M6 Turbo 8.4",
    "VRD-AL09": "Huawei MediaPad M6 Turbo 8.4",
    "VOG-TL00": "Huawei P30 Pro",
    "VOG-L29": "Huawei P30 Pro",
    "VOG-L09": "Huawei P30 Pro",
    "VOG-L04": "Huawei P30 Pro",
    "VOG-AL10": "Huawei P30 Pro",
    "VOG-AL00": "Huawei Y6 Pro",
    "VNS-TL00": "Huawei G9 Lite",
    "VNS-L62": "Huawei P9 Lite",
    "VNS-L53": "Huawei P9 lite",
    "VNS-L52C": "Huawei VNS-L52C",
    "VNS-L31": "Huawei P9 Lite",
    "VNS-L23": "Huawei P9 lite",
    "VNS-L22": "Huawei P9 Lite",
    "VNS-L21": "Huawei P9 Lite",
    "VNS-DL00": "Huawei P9",
    "VNS-AL00": "Huawei G9 Lite",
    "VKY-TL00": "Huawei P10 Plus",
    "VKY-L29": "Huawei P10 Plus",
    "VKY-L09": "Huawei P10 Plus",
    "VKY-AL00": "Huawei P10 Plus",
    "VIE-L29": "Huawei P9 Plus",
    "VIE-L09": "Huawei P9 Plus",
    "VIE-C00": "Huawei P9 Plus",
    "VIE-AL10": "Huawei P9 Plus",
    "Victoria-L09": "Huawei P10",
    "Vicky-L29": "Huawei P10 Plus",
    "Vicky-L09": "Huawei P10 Plus",
    "VEN-L22": "Huawei Honor 8 Smart",
    "VCE-TL00": "Huawei Nova 4",
    "VCE-AL00": "Huawei Nova 4",
    "U9510E": "Huawei Ascend D1",
    "U9508": "Huawei Honor 2",
    "U9202L-1": "Huawei Ascend P1 LTE",
    "U9200-1": "Huawei Ascend P1",
    "TRT-TL10": "Huawei Y7 Prime",
    "TRT-LX3": "Huawei Y7",
    "TRT-LX1": "Huawei Y7",
    "TRT-LX": "Huawei Y7 Prime",
    "TRT-L53D": "Huawei Y7 Prime",
    "TRT-L53": "Huawei Y7 Prime",
    "TRT-L21A": "Huawei Y7 Prime",
    "TRT-L21": "Huawei Y7",
    "TRT-L03": "Huawei Y7",
    "TRT-L02": "Huawei Y7",
    "TRT-L01": "Huawei Y7",
    "TRT-AL00": "Huawei Enjoy 7 Plus",
    "Toronto-L23": "Huawei Y7",
    "Toronto-L22": "Huawei Toronto-L22",
    "Toronto-L21": "Huawei Y7",
    "Toronto-L02": "Huawei Toronto-L02",
    "Toronto-AL00": "Huawei Toronto-AL00",
    "TNY-TL00": "Huawei Honor Magic 2",
    "TNY-AL10": "Honor Magic 2",
    "TNY-AL00": "Honor Magic 2",
    "TNNH-AN00": "Honor Play4",
    "TNN-AN00": "Huawei Enjoy 20s",
    "TIT-U02": "Huawei Y6 Pro",
    "TIT-L01": "Huawei Y6 Pro",
    "TIT-CL10": "Huawei Enjoy 5",
    "TIT-CL00": "Huawei Enjoy 5",
    "TIT-AL00": "Huawei Y6 Pro",
    "TET-AN00": "Huawei Mate X2",
    "TEL-AN10": "Honor X10 5G",
    "TEL-AN00A": "Honor X10 5G",
    "TEL-AN00": "Honor X10 5G",
    "TAS-TL00": "Huawei Mate 30",
    "TAS-L29": "Huawei Mate 30",
    "TAS-AN00": "Huawei Mate 30 5G",
    "TAS-AL00": "Huawei Mate 30",
    "TAH-N29M": "Huawei Mate Xs",
    "TAH-AN00M": "Huawei Mate X",
    "TAH-AN00": "Huawei Mate X",
    "TAG-TL00": "Huawei Enjoy 5s",
    "TAG-L32": "Huawei GR3",
    "TAG-L23": "Huawei GR3",
    "TAG-L22": "Huawei GR3",
    "TAG-L21": "Huawei GR3",
    "TAG-L13": "Huawei GR3",
    "TAG-L03": "Huawei GR3",
    "TAG-L01": "Huawei P8 Lite Smart",
    "TAG-CL00": "Huawei Enjoy 5S",
    "T1-A22L": "Huawei Mediapad T1",
    "T1-A21w": "Huawei MediaPad T1 10",
    "T1-A21L": "Huawei MediaPad T1 10",
    "T1-821L": "Huawei MediaPad T1 8.0",
    "T1-702u": "Huawei MediaPad T1 7.0",
    "T1-702": "Huawei MediaPad T1 7.0",
    "T1-701w": "Huawei MediaPad T1 7.0",
    "T1-701ua": "Huawei MediaPad T1 7.0",
    "T1-701u": "Huawei MediaPad T1 7.0",
    "T1-701": "Huawei MediaPad T1 7.0",
    "STK-TL00": "Huawei Enjoy 10 Plus",
    "STK-L23BHN": "Huawei Y9 Prime (2019)",
    "STK-L22HN": "Huawei Y9 Prime (2019)",
    "STK-L22DV": "Huawei Y9 Prime (2019)",
    "STK-L22": "Huawei Y9 Prime (2019)",
    "STK-L21VHN": "Huawei Y9 Prime (2019)",
    "STK-L21UDV": "Huawei Y9 Prime (2019)",
    "STK-L21MDV": "Huawei Y9 Prime (2019)",
    "STK-L21M": "Huawei Y9 Prime (2019)",
    "STK-L21HN": "Huawei Y9 Prime (2019)",
    "STK-L21": "Huawei Y9 Prime (2019)",
    "STK-L03DV": "Huawei P Smart Z",
    "STK-L03B": "Huawei P Smart Z",
    "STK-L01MDV": "Huawei Y9 Prime (2019)",
    "STK-L01M": "Huawei P Smart Z",
    "STK-AL00": "Huawei P Smart Z",
    "STF-TL10": "Huawei Honor 9",
    "STF-L09S": "Huawei Honor 9",
    "STF-L09": "Huawei Honor 9",
    "STF-AL10": "Huawei Honor 9",
    "STF-AL00": "Huawei Honor 9",
    "SPN-AL10": "Huawei nova 5z",
    "SPN-AL00": "Huawei nova 5z",
    "Sophia-L12": "Huawei Ascend P7",
    "Sophia-L11": "Huawei Ascend P7",
    "Sophia-L10": "Huawei Ascend P7",
    "Sophia-L09": "Huawei Ascend P7",
    "Sophia-L07": "Huawei Ascend P7",
    "Sophia-L00": "Huawei Ascend P7",
    "SNE-L01": "Huawei Mate 20 lite",
    "SLA-L22": "Huawei P9 Lite Mini",
    "SLA-L03": "Huawei Y6 Pro 2017",
    "SLA-L02": "Huawei Y6 Pro 2017",
    "SLA-AL00": "Huawei Enjoy 7",
    "SHT-W09": "Huawei MediaPad M5 8.4",
    "SHT-AL09": "Huawei MediaPad M5 8.4",
    "Selina-L03": "Huawei Y6 Pro 2017",
    "SEA-AL10": "Huawei nova 5 Pro",
    "SEA-AL00": "Huawei nova 5",
    "SCMR-W09": "Huawei MatePad 10.8",
    "SCMR-AL09": "Huawei MatePad 10.8",
    "SCL-U31": "Huawei Y6",
    "SCL-U23": "Huawei Y6",
    "SCL-L32": "Huawei Y6",
    "SCL-L21": "Huawei Y6",
    "SCL-L04": "Huawei Y6",
    "SCL-L03": "Huawei Y6",
    "SCL-L02": "Huawei Y6",
    "SCL-L01": "Huawei Y6",
    "SCL-CL00": "Huawei Honor 4A",
    "SCL-AL00": "Huawei Honor 4A",
    "SCC-U21": "Huawei Y6",
    "SC-CL00": "Huawei Ascend GX1",
    "S8-701w": "Huawei MediaPad T1 8.0",
    "S8-701u": "Huawei MediaPad M1 8.0",
    "S8-306L": "Huawei MediaPad M1 8.0",
    "S8-303L": "Huawei MediaPad M1",
    "S8-301w": "Huawei MediaPad M1 8.0",
    "S8-301u": "Huawei MediaPad M1 8.0",
    "S8-301L": "Huawei MediaPad M1 8.0",
    "S7-931w": "Huawei MediaPad 7 Lite",
    "S7-931u": "Huawei MediaPad 7 Lite",
    "S7-722u": "Huawei MediaPad 7 Youth 2",
    "S7-721w": "Huawei MediaPad 7 Youth 2",
    "S7-721u": "Huawei MediaPad 7 Youth 2",
    "S7-721g": "Huawei MediaPad 7 Youth 2",
    "S7-701w": "Huawei MediaPad 7 Youth",
    "S7-701u": "Huawei MediaPad 7 Youth",
    "S7-601w": "Huawei MediaPad 7 Vogue",
    "S7-601u": "Huawei MediaPad 7 Vogue",
    "S7-301u": "Huawei MediaPad 7 Vogue",
    "S7-201u": "Huawei IDEOS S7 Slim",
    "S10-232L": "Huawei MediaPad 10 Link Plus",
    "S10-231w": "Huawei MediaPad10 Link",
    "S10-231u": "Huawei MediaPad 10 Link Plus",
    "S10-231L": "Huawei MediaPad 10 Link",
    "S10-201u": "Huawei MediaPad 10 Link",
    "S10-101w": "Huawei MediaPad 10 FHD",
    "S10-101u": "Huawei MediaPad 10 FHD",
    "RVL-AL09": "Honor Note 10",
    "RNE-L23": "Huawei Mate 10 Lite",
    "RNE-L22": "Huawei Nova 2i",
    "RNE-L21": "Huawei Mate 10 Lite",
    "RNE-L03": "Huawei Mate 10 Lite",
    "RNE-L02": "Huawei Nova 2i",
    "RNE-L01": "Huawei Mate 10 Lite",
    "RNE-AL00": "Huawei Maimang 6",
    "RIO-UL00": "Huawei G7 Plus",
    "RIO-TL00": "Huawei G7 Plus",
    "RIO-L33": "Huawei G8",
    "RIO-L23": "Huawei G8",
    "RIO-L11": "Huawei G8",
    "RIO-L03": "Huawei GX8",
    "RIO-L02": "Huawei G8",
    "RIO-L01,RIO-L11": "Huawei G8",
    "RIO-L01": "Huawei G8",
    "RIO-CL00": "Huawei Maimang 4",
    "RIO-AL00": "Huawei Maimang 4",
    "Rhone-L21": "Huawei Mate 10 Lite",
    "Rhone-L03": "Huawei Mate 10 Lite",
    "Rhone-L01": "Huawei Mate 10 Lite",
    "Prague-TL00": "Huawei Prague-TL00",
    "Prague-L23": "Huawei P8 Lite 2017",
    "Prague-L22": "Huawei P8 Lite 2017",
    "Prague-L21": "Huawei P8 Lite 2017",
    "Prague-L03": "Huawei Prague-L03",
    "PRA-TL10": "Huawei Honor 8 Lite",
    "PRA-LX3": "Huawei P9 Lite 2017",
    "PRA-LX2": "Huawei Nova Lite",
    "PRA-LX1": "Huawei P8 Lite 2017",
    "PRA-LA1": "Huawei Honor 8 Lite",
    "PRA-L31": "Huawei P8 Lite 2017",
    "PRA-L22": "Huawei P8 Lite 2017",
    "PRA-L21": "Huawei P8 Lite Dual Sim 2017",
    "PRA-L11": "Huawei P8 Lite 2017",
    "PRA-L03": "Huawei P8 Lite 2017",
    "PRA-L02": "Huawei Nova Lite",
    "PRA-L01": "Huawei P8 Lite 2017",
    "PRA-AL00X": "Huawei Honor 8 Lite",
    "PRA-AL00": "Huawei Honor 8 Lite",
    "PPAH-TL20": "Huawei P smart 2021",
    "PPAH-L22": "Huawei P smart 2021",
    "PPAH-L21": "Huawei P smart 2021",
    "PPAH-L02": "Huawei P smart 2021",
    "PPAH-AL40": "Huawei P smart 2021",
    "PPAH-AL20": "Huawei P smart 2021",
    "POT-TL00": "Huawei Enjoy 9s",
    "POT-LX3": "Huawei P Smart 2019",
    "POT-LX2J": "Huawei Nova Lite 3",
    "POT-LX1A": "Huawei P Smart 2020",
    "POT-LX1": "Huawei P Smart 2019",
    "POT-L41B": "Huawei P Smart S",
    "POT-L21RU": "Huawei P smart 2019",
    "POT-L21": "Huawei P smart 2019",
    "POT-L01": "Huawei P smart 2019",
    "POT-AL10C": "Huawei enjoy 9s",
    "POT-AL00a": "Huawei Enjoy 9S",
    "POT-AL00": "Huawei P Smart 2019",
    "PLK-UL00IN": "Huawei Honor 7",
    "PLK-UL00": "Huawei Honor 7",
    "PLK-TL01H": "Huawei Honor 7",
    "PLK-TL00": "Huawei Honor 7",
    "PLK-L01": "Huawei Honor 7",
    "PLK-CL00": "Huawei Honor 7",
    "PLK-AL10": "Huawei Honor 7",
    "PLE-703L": "Huawei MediaPad M2 Lite",
    "PLE-701L": "Huawei MediaPad T2 7.0",
    "Pine-UL00": "Huawei Honor 6 plus",
    "Pine-TL10": "Huawei Honor 6 Plus",
    "Pine-L04": "Huawei Honor 6 Plus",
    "Pine-L02": "Huawei Honor 6 Plus",
    "Pine-L00": "Huawei Honor 6 Plus",
    "PIC-TL00": "Huawei Nova 2",
    "PIC-LX9": "Huawei Nova 2",
    "PIC-L29": "Huawei Nova 2",
    "PIC-L09": "Huawei Nova 2",
    "PIC-AL00": "Huawei Nova 2",
    "PE-UL00": "Huawei Honor 6 Plus",
    "PE-TL20": "Huawei Honor 6 Plus",
    "PE-TL10": "Huawei Honor 6 Plus",
    "PE-TL00M": "Huawei Honor 6 Plus",
    "PE-CL00": "Huawei Honor 6 Plus",
    "PCT-TL10": "Honor View 20",
    "PCT-L29D": "Honor View 20",
    "PCT-L29": "Honor View 20",
    "PCT-AL10D": "Honor View 20",
    "PCT-AL10": "Honor View 20",
    "Paris-L09A": "Huawei Nova 3",
    "PAR-TL20": "Huawei Nova 3",
    "PAR-TL00": "Huawei nova 3",
    "PAR-AL00": "Huawei nova 3",
    "P7-L10": "Huawei Ascend P7",
    "P7-L09": "Huawei Ascend P7",
    "P7-L07": "Huawei Ascend P7",
    "P7-L05": "Huawei Ascend P7",
    "P6-U06": "Huawei Ascend P6",
    "P6-S-U00": "Huawei Ascend P6 S",
    "P2-6011": "Huawei Ascend P2",
    "OXF-AN10L": "Honor V30 Pro",
    "OXF-AN10": "Honor V30 Pro",
    "OXF-AN00L": "Honor V30",
    "OXF-AN00": "Honor V30",
    "OCE-AN50": "Huawei Mate 40E",
    "OCE-AN10": "Huawei Mate 40E",
    "NXT-TL00": "Huawei Mate 8",
    "NXT-L29B": "Huawei Ascend Mate8",
    "NXT-L29A": "Huawei Ascend Mate8",
    "NXT-L29": "Huawei Mate 8",
    "NXT-L09A": "Huawei Ascend Mate8",
    "NXT-L09": "Huawei Mate 8",
    "NXT-DL00": "Huawei Mate 8",
    "NXT-CL00": "Huawei Mate 8",
    "NXT-C00": "Huawei Mate 8",
    "NXT-AL10": "Huawei Mate 8",
    "MAR-L01MEA": "Huawei P30 lite",
    "MAR-L01B": "Huawei P30 lite",
    "MAR-L01A": "Huawei P30 lite",
    "MAR-AL00": "Huawei nova 4e",
    "Madrid-L21": "Huawei Y6 (2019)",
    "M2-A01w": "Huawei MediaPad M2 10.0",
    "M2-A01L": "Huawei MediaPad M2 10.0",
    "M2-803L": "Huawei MediaPad M2 8.0",
    "M2-802L": "Huawei MediaPad M2 8.0",
    "M2-801w": "Huawei MediaPad M2 8.0",
    "M2-801L": "Huawei MediaPad M2 8.0",
    "LYO-L21": "Huawei Honor 5A",
    "LYO-L02": "Huawei Y6 II",
    "LYO-L01": "Huawei Y6 II",
    "LYA-TL00L": "Huawei Mate 20 Pro",
    "LYA-TL00": "Huawei Mate 20 Pro",
    "LYA-L29": "Huawei Mate 20 Pro",
    "LYA-L09": "Huawei Mate 20 Pro",
    "LYA-AL10": "Huawei Mate 20 Pro",
    "LYA-AL00P": "Huawei Mate 20 Pro",
    "LYA-AL00L": "Huawei Mate 20 Pro",
    "LYA-AL00": "Huawei Mate 20 Pro",
    "LUA-U23": "Huawei Y3 II",
    "LUA-U22": "Huawei Y3 II",
    "LUA-U03": "Huawei Y3 II",
    "LUA-U02": "Huawei Y3 II",
    "LUA-L23": "Huawei Y3 II",
    "LUA-L22HN": "Huawei Honor Bee 2",
    "LUA-L22": "Huawei Y3 II",
    "LUA-L21": "Huawei Y3 II",
    "LUA-L13": "Huawei Y3 II",
    "LUA-L03": "Huawei Y3 II",
    "LUA-L02": "Huawei Y3 II",
    "LUA-L01": "Huawei Y3 II",
    "LRA-L21B": "Honor 30i",
    "LRA-AL00": "Honor 20 lite (China)",
    "LON-L29D": "Huawei Mate 9 Pro",
    "LON-L29C": "Huawei Mate 9 Pro",
    "LON-L29": "Huawei Mate 9 Pro",
    "LON-AL00": "Huawei Mate 9 Pro",
    "LLD-TL10": "Honor 9 Lite",
    "LLD-L31": "Huawei Honor 9 Lite",
    "LLD-L21": "Huawei Honor 9 Lite",
    "LLD-AL30": "Honor 9N (9i)",
    "LLD-AL20": "Honor 9N (9i)",
    "LLD-AL10": "Huawei Honor 9 Lite",
    "LLD-AL00": "Huawei Honor 9 Lite",
    "LIO-TL00": "Huawei Mate 30 Pro",
    "LIO-N29": "Huawei Mate 30 RS Porsche Design",
    "LIO-L29": "Huawei Mate 30 Pro 5G",
    "LIO-AN00P": "Huawei Mate 30 RS Porsche Design",
    "LIO-AN00M": "Huawei Mate 30 Pro",
    "LIO-AN00": "Huawei Mate 30 Pro 5G",
    "LIO-AL00": "Huawei Mate 30 Pro",
    "LDN-TL10": "Huawei Y7 Prime 2018",
    "LDN-TL00": "Huawei Enjoy 8",
    "LDN-LX3": "Huawei Y7 2018",
    "LDN-LX2": "Huawei Y7 Prime 2018",
    "LDN-L22": "Huawei nova 2 lite",
    "LDN-L21": "Huawei Y7 2018",
    "LDN-L03": "Huawei Y7 2018",
    "LDN-L01": "Huawei Y7 2018",
    "LDN-AL00": "Huawei Enjoy 8",
    "KSA-L29": "Honor 8S",
    "KSA-L22": "Honor 8S",
    "KSA-L09": "Honor 8S",
    "KSA-AL10": "Honor 8S",
    "KSA-AL00": "Honor 8S",
    "KRJ-W09": "Honor V6",
    "KRJ-AN00": "Honor V6",
    "KOB2-W09B": "Huawei MatePad T8",
    "KOB2-W09": "Huawei MatePad T8",
    "KOB2-L09B": "Huawei MatePad T8",
    "KOB2-L09": "Huawei MatePad T8",
    "KOB-W09": "HUAWEI MediaPad T3",
    "KOB-L09": "Huawei Mediapad T3",
    "KNT-UL10": "Huawei Honor V8",
    "KNT-TL10": "Huawei Honor V8",
    "KNT-C00": "Huawei Honor V8",
    "KNT-AL20": "Huawei Honor V8",
    "KNT-AL10": "Huawei Honor V8",
    "KKG-TN00": "Honor X10 Max 5G",
    "KKG-AN00": "Honor X10 Max 5G",
    "KIW-UL00": "Huawei Honor 5X",
    "KIW-TL00": "Huawei Honor 5X",
    "KIW-L24": "Huawei Honor 5X",
    "KIW-L22": "Huawei Honor 5X",
    "KIW-L21": "Huawei HONOR 5X",
    "KIW-CL00": "Huawei Honor 5X",
    "KIW-AL10": "Huawei Honor 5X",
    "KII-L33": "Huawei GR5",
    "KII-L23": "Huawei GR5",
    "KII-L22": "Huawei GR5",
    "KII-L21": "Huawei GR5",
    "KII-L05": "Huawei GR5",
    "JSN-TL00": "Honor 8X",
    "JSN-L22X": "Honor 8X",
    "JSN-L21X": "Honor 8X",
    "JSN-L21": "Honor 8X",
    "JSN-AL00": "Honor 8X",
    "JSC-AN00A": "Huawei nova 8 SE",
    "JSC-AN00": "Huawei nova 8 SE",
    "JNY-L22": "Huawei nova 7i",
    "JNY-L21": "Huawei nova 7i",
    "JNY-L01": "Huawei nova 7i",
    "JNY-AL10": "Huawei nova 6 SE",
    "JMM-TL00": "Huawei Honor 6C Pro",
    "JMM-L22": "Huawei Honor 6C Pro",
    "JMM-AL00": "Huawei Honor 6C Pro",
    "JKM-TL00": "Huawei Y9 (2019)",
    "JKM-LX3": "Huawei Y9 (2019)",
    "JKM-LX2": "Huawei Y9 (2019)",
    "JKM-LX1": "Huawei Y9 (2019)",
    "JKM-L21X": "Huawei Y9 (2019)",
    "JKM-L21": "Huawei Y9 (2019)",
    "JKM-L01X": "Huawei Y9 (2019)",
    "JKM-AL20": "Huawei Y9 (2019)",
    "JKM-AL10": "Huawei Y9 (2019)",
    "JKM-AL00": "Huawei Y9 (2019)",
    "Jimmy-TL00": "Huawei Jimmy TL00",
    "Jimmy-AL00": "Huawei Jimmy-AL00",
    "JER-TN20": "Huawei nova 7 Pro 5G",
    "JER-TN10": "Huawei nova 7 Pro 5G",
    "JER-AN20": "Huawei nova 7 Pro 5G",
    "JER-AN10": "Huawei Nova 7 Pro",
    "JEF-TN20": "Huawei nova 7 5G",
    "JEF-TN00": "Huawei nova 7 5G",
    "JEF-AN20": "Huawei nova 7 5G",
    "JEF-AN00": "Huawei Nova 7 Pro",
    "JDN2-W09HN": "Honor Tab 5",
    "JDN2-W09": "Honor Tab 5",
    "JDN2-L09": "Huawei MediaPad M5 Lite 8",
    "JDN2-AL50HN": "Huawei MediaPad M5 lite",
    "JDN2-AL50": "Huawei MediaPad M5 lite",
    "JDN2-AL00HN": "Honor Pad 5 8",
    "JDN2-AL00": "Honor Pad 5 8",
    "JDN-W09": "Huawei Honor Pad 2",
    "JDN-L01": "Huawei MediaPad T2 8.0",
    "JDN-AL00": "Huawei Honor Pad 2",
    "Jazz-TL10": "Huawei Ascend Mate 7",
    "Jazz-L11": "Huawei Ascend Mate 7",
    "Jazz-L09": "Huawei Ascend Mate 7",
    "Jazz-J1": "Huawei Ascend Mate 7",
    "JAT-TL00": "Huawei Honor 8A",
    "JAT-L41HW": "Honor 8A Pro",
    "JAT-L41": "Honor 8A Pro",
    "JAT-L29HW": "Honor Play 8A",
    "JAT-L29": "Honor Play 8A",
    "JAT-L23HW": "Honor Play 8A",
    "JAT-L21AHW": "Honor 8A Pro",
    "JAT-AL00": "Honor Play 8A",
    "Jakarta-LGRP2": "Huawei Y9 (2019)",
    "Jackman-L22": "Huawei Y9 (2019)",
    "INE-TL00": "Huawei Nova 3i",
    "INE-LX2": "Huawei Nova 3i",
    "INE-LX1": "Huawei Nova 3i",
    "INE-LGRP1": "Huawei Nova 3i",
    "INE-L22rr": "Huawei Nova 3i",
    "INE-L22": "Huawei Nova 3i",
    "INE-L21": "Huawei Nova 3i",
    "INE-AL00": "Huawei nova 3i",
    "HWI-TL00": "Huawei Nova 2S",
    "HWI-LGRP1": "Huawei Nova 2S",
    "HWI-AL00": "Huawei Nova 2s",
    "HRY-TL00": "Honor 10 Lite",
    "HRY-L21T": "Honor 10 Lite",
    "HRY-L21D": "Honor 10 Lite",
    "HRY-L21": "Honor 10 Lite",
    "HRY-LX1": "Honor 10 Lite",
    "HRY-LX2": "Honor 10 Lite",
    "HRY-AL00a": "Honor 10 Lite",
    "HRY-LX1MEB": "Honor 10 Lite",
    "HRY-AL00TA": "Honor 20i",
    "HRY-AL00T": "Honor 10 Lite",
    "HRY-AL00A": "Honor 10 Lite",
    "HRY-AL00": "Honor 10 Lite",
    "Holly-U19": "Huawei Holly",
    "Holly-U10": "Huawei Holly",
    "Holly-U00": "Huawei Honor 3C",
    "HMA-TL00": "Huawei Mate 20",
    "HMA-L29": "Huawei Mate 20",
    "HMA-L09": "Huawei Mate 20",
    "HMA-AL00": "Huawei Mate 20",
    "HLK-L42": "Honor 9X Pro",
    "HLK-L41": "Honor 9X Pro",
    "HLK-AL10": "Honor 9X",
    "HLK-AL00A": "Honor 9X",
    "HLK-AL00": "Honor 9X (China)",
    "HDN-W09": "Huawei Honor",
    "H60-L12": "Huawei Honor 6",
    "H60-L04": "Huawei Honor 6",
    "H60-L03": "Huawei Honor 6",
    "H60-L02": "Huawei Honor 6",
    "H60-L01": "Huawei Honor 6",
    "H60-J1": "Huawei Honor 6",
    "H30-U10": "Huawei 3C",
    "H30-L02": "Huawei Honor 3C",
    "H30-L01": "Huawei Honor 3C",
    "GRA-UL10": "Huawei P8",
    "GRA-UL00": "Huawei P8",
    "GRA-TL00": "Huawei P8",
    "GRA-L13": "Huawei P8",
    "GRA-L09": "Huawei P8",
    "GRA-L03": "Huawei P8",
    "GRA-CL10": "Huawei P8",
    "GRA-CL00": "Huawei P8 Standard Edition",
    "GLK-TL00": "Huawei nova 5i",
    "GLK-AL00": "Huawei nova 5i",
    "GEM-703L": "HUAWEI Honor X2",
    "GEM-703": "Huawei MediaPad X2",
    "GEM-702L": "Huawei MediaPad X2",
    "GEM-702": "Huawei MediaPad X2",
    "GEM-701L": "Huawei MediaPad X2",
    "GEM-701": "Huawei MediaPad X2",
    "G760-TL00": "Huawei Ascend G7",
    "G760-L03": "Huawei Ascend G7",
    "G760-L01": "Huawei Ascend G7",
    "G750-U10": "Huawei Honor 3X",
    "G750-T20": "Huawei Honor 3X",
    "G750-C00": "Huawei Honor 3X",
    "G740-L00": "Huawei G740",
    "G735-L23": "Huawei G Play",
    "G735-L12": "Huawei G Play",
    "G735-L03": "Huawei G Play",
    "G730-U251": "Huawei G730",
    "G730-U10": "Huawei G730",
    "G700-U20": "Huawei Ascend G700",
    "G700-U10": "Huawei Ascend G700",
    "G7-L11": "Huawei Ascend G7",
    "G7-L01": "Huawei Ascend G7",
    "G630-U251": "Huawei G630",
    "G630-U20": "Huawei G630",
    "G630-U10": "Huawei G630",
    "G630-U00": "Huawei G630",
    "G629-UL00": "Huawei G629",
    "G628-TL00": "Huawei Ascend G628",
    "G620S-UL00": "Huawei Ascend G620s",
    "G620S-L03": "Huawei Ascend G620s",
    "G620S-L02": "Huawei Ascend G620s",
    "G620S-L01": "Huawei Ascend G620s",
    "G620-UL01": "Huawei G620",
    "G620-L75": "Huawei Ascend G620s",
    "G620-L72": "Huawei G620",
    "G615-U10": "Huawei Ascend G615",
    "G610-U20": "Huawei G610",
    "G610-U15": "Huawei G610",
    "G610-U00": "Huawei Ascend G6",
    "G6-U251": "Huawei Ascend G6",
    "G6-U10": "Huawei Ascend G6",
    "G6-L33": "Huawei Ascend G6",
    "G6-L22": "Huawei Ascend G6",
    "G6-L11": "Huawei Ascend G6",
    "G527-U081": "Huawei Ascend G527",
    "G526-L33": "Huawei Ascend G526",
    "G525-U00": "Huawei Ascend G525",
    "G510-0251": "Huawei Ascend G510",
    "G510-0200": "Huawei Ascend G510",
    "G510-0100": "Huawei Ascend G510",
    "FRLM-TN00": "Huawei Enjoy 20 SE",
    "FRLM-L22": "Huawei Enjoy 20 SE",
    "FRLM-L03": "Huawei Enjoy 20 SE",
    "FRLM-AN00A": "Huawei Enjoy 20 SE",
    "FRD-L19": "Huawei Honor 8",
    "FRD-L14": "Huawei Honor 8",
    "FRD-L09": "Huawei HONOR 8",
    "FRD-L04": "Huawei Honor 8",
    "FRD-L02": "Huawei HONOR 8",
    "FRD-DL00": "Huawei MediaPad T2 10.0 Pro",
    "FRD-C00": "Huawei Honor 8",
    "FRD-AL10": "Huawei Honor 8",
    "FRD-AL00": "Huawei Honor 8",
    "FLA-TL10": "Huawei Y9 (2018)",
    "FLA-AL20": "Huawei Y9 2018",
    "FLA-AL10": "Huawei Y9 2018",
    "FLA-AL00": "Huawei Y9 2018",
    "Figo-L31": "Huawei P Smart",
    "FIG-TL10": "Huawei Enjoy 7S Dual",
    "FIG-TL00": "Huawei P smart",
    "FIG-LX3": "Huawei P Smart",
    "FIG-LX2": "Huawei P Smart",
    "FIG-LX1": "Huawei P Smart Dual SIM",
    "FIG-LA1": "Huawei P Smart",
    "FIG-L31": "Huawei P Smart",
    "FIG-L22": "Huawei P Smart",
    "FIG-L21": "Huawei P Smart",
    "FIG-L11": "Huawei P Smart",
    "FIG-L03": "Huawei P Smart",
    "FIG-L02": "Huawei P Smart",
    "FIG-AL10": "Huawei Enjoy 7S",
    "FIG-AL00": "Huawei P smart",
    "FDR-A05": "Huawei MediaPad T2 10.0 Pro",
    "FDR-A04": "Huawei MediaPad T2 10.0 Pro",
    "FDR-A03L": "Huawei M2",
    "FDR-A03": "Huawei MediaPad T2 10.0 Pro",
    "FDR-A01w": "Huawei MediaPad T2 10.0 Pro",
    "FDR-A01": "Huawei MediaPad T2 10.0 Pro",
    "EVR-TL00": "Huawei Mate 20 X",
    "EVR-N29": "Huawei Mate 20 X (5G)",
    "EVR-L29": "Huawei Mate 20 X",
    "EVR-AN00": "Huawei Mate 20 X (5G)",
    "EVR-AL00": "Huawei Mate 20 X",
    "EVA-L29": "Huawei P9",
    "EVA-L19": "Huawei P9",
    "EVA-L09": "Huawei P9",
    "EVA-DL00": "Huawei P9",
    "EVA-CL00": "Huawei P9",
    "EVA-C00": "Huawei P9",
    "EVA-AL10": "Huawei P9",
    "EVA-AL00": "Huawei P9",
    "EML-L29": "Huawei P20",
    "EML-L09": "Huawei P20",
    "EML-AL00": "Huawei P20",
    "ELS-TN00": "Huawei P40 Pro",
    "ELS-N39": "Huawei P40 Pro+",
    "ELS-N29": "Huawei P40 Pro+",
    "ELS-N04": "Huawei P40 Pro",
    "ELS-AN10": "Huawei P40 Pro+",
    "ELS-AN00": "Huawei P40 Pro",
    "ELE-TL00": "Huawei P30",
    "ELE-L29": "Huawei P30",
    "ELE-L09": "Huawei P30",
    "ELE-L04": "Huawei P30",
    "ELE-AL00": "Huawei P30",
    "EDI-AL10": "Huawei Honor Note 8",
    "EDGE-U00": "Huawei Ascend P6",
    "EDGE-C00": "Huawei Ascend P6",
    "EBG-TN00": "Honor 30 Pro",
    "EBG-N19": "Honor 30 Pro+",
    "EBG-AN10": "Honor 30 Pro+",
    "EBG-AN00": "Honor 30 Pro",
    "DVCM-TN20": "",
    "DVCM-AN20": "Huawei Enjoy 20 Pro",
    "DVCM-AN00": "Huawei Enjoy 20 Pro",
    "DUK-TL30": "Huawei Honor V9",
    "DUK-L09": "Huawei Honor 8 Pro",
    "DUK-AL30": "Huawei Honor V9",
    "DUK-AL20": "Huawei Honor V9",
    "DUB-LX3": "Huawei Y7 Prime 2019",
    "DUB-LX1": "Huawei Y7 Prime 2019",
    "DUB-L01": "Huawei Y7 2019",
    "DUB-AL00": "Huawei Enjoy 9",
    "DUA-L29": "Honor 9S",
    "DRA-LX5": "Huawei Y5 Lite (2018)",
    "DRA-L29": "Huawei Y5p",
    "DRA-L21": "Huawei Y5 Prime 2018",
    "DRA-L09": "Huawei Y5p",
    "DNN-L29": "Honor 10X Lite",
    "Diego-TL10": "Huawei Enjoy 6S",
    "Diego-L23": "Huawei Diego-L23",
    "Diego-L21": "Huawei Honor 6C",
    "Diego-L03": "Huawei Diego-L03",
    "Diego-L01": "Huawei Diego-L01",
    "Diego-AL00": "Huawei Diego-AL00",
    "Delhi-TL20": "Huawei Honor 6A",
    "Delhi-L42": "Huawei Honor 6A",
    "Delhi-L22": "Huawei Honor 6A",
    "Delhi-AL10": "Huawei Honor 6A",
    "DAV-703": "Huawei P8 MAX",
    "DAV-702L": "Huawei P8 max",
    "DAV-701L": "Huawei P8 max",
    "D2-0082": "Huawei Ascend D2",
    "CUN-U29": "Huawei Y5 II",
    "CUN-TL00": "Huawei Honor 5",
    "CUN-L33": "Huawei Y5 II",
    "CUN-L23": "Huawei Y5 II",
    "CUN-L22": "Huawei Y5 II",
    "CUN-L21": "Huawei Y5 II",
    "CUN-L03": "Huawei Y5 II",
    "CUN-L02": "Huawei Y5 II",
    "CUN-L01": "Huawei Y5 II",
    "CUN-AL00": "Huawei Honor 5",
    "CRR-UL20": "Huawei Mate S",
    "CRR-UL00": "Huawei Mate S",
    "CRR-TL00": "Huawei Mate S",
    "CRR-L13": "Huawei Mate S",
    "CRR-L09": "Huawei Mate S",
    "CRR-CL20": "Huawei Mate S",
    "CRR-CL00": "Huawei Mate S",
    "CRO-UL00": "Huawei Y3 2017",
    "CRO-L03": "Huawei Y3 2017",
    "CRO-L02": "Huawei Y3 2017",
    "CPN-W09": "Huawei M3 Lite",
    "CPN-L09": "Huawei MediaPad M3 Lite",
    "CPN-AL00": "Huawei M3 Lite",
    "COR-TL10": "Honor Play",
    "COR-AL10": "Honor Play",
    "COR-AL00": "Honor Play",
    "COL-TL10": "Huawei Honor 10",
    "COL-TL00": "Huawei Honor 10",
    "COL-L29": "Huawei Honor 10",
    "COL-AL10": "Honor 10",
    "CND-AN00": "Huawei nova 7 SE 5G Youth",
    "CMR-W19": "Huawei MediaPad M5 Pro 10.8",
    "CMR-W09TWN": "Huawei MediaPad M5",
    "CMR-W09": "Huawei MediaPad M5 10.8",
    "CMR-AL19": "Huawei MediaPad M5 Pro 10.8",
    "CMR-AL09": "Huawei MediaPad M5 10.8",
    "CM990": "Huawei CM990",
    "CLT-TL00": "Huawei P20 Pro",
    "CLT-L29": "Huawei P20 Pro Dual SIM",
    "CLT-L09": "Huawei P20 Pro Dual SIM",
    "CLT-L04": "Huawei P20 Pro Dual SIM",
    "CLT-AL01": "Huawei P20 Pro Dual SIM",
    "CLT-AL00": "Huawei P20 Pro Dual SIM",
    "CHM-UL00": "Huawei Honor 4C",
    "CHM-U01": "Huawei Honor 4C",
    "CHM-TL00H": "Huawei Honor 4C",
    "CHM-TL00": "Huawei Honor 4C",
    "CHM-CL00": "Huawei Honor 4C",
    "CHL-AL60CH": "Huawei nova 8 SE",
    "CherryPlus-TL00": "Huawei Honor 4X",
    "CherryPlus-L23": "Huawei Honor 4X",
    "CherryPlus-L12": "Huawei Honor 4X LTE",
    "CherryPlus-L11": "Huawei HONOR 4X",
    "Cherry-L04": "Huawei Honor 4X",
    "Cherry-CL20": "Huawei Honor 4X",
    "Cherry-CL10": "Huawei Honor 4X",
    "CHE2-L12": "Huawei Honor 4X",
    "Che2-L11": "Huawei Honor 4X",
    "CHE1-L04": "Huawei Honor 4X",
    "CHE1-CL20": "Huawei Honor 4X",
    "CHE1-CL10": "Huawei Honor 4X",
    "CHE-TL00H": "Huawei Honor 4x",
    "CHE-TL00": "Huawei Honor 4X",
    "Che-L11": "Huawei Honor 4X",
    "CHC-U23": "Huawei G Play Mini",
    "CHC-U03": "Huawei G Play mini",
    "CHC-U01": "Huawei G Play Mini",
    "CDY-TN90": "Honor 30S",
    "CDY-TN20": "Huawei nova 7 SE",
    "CDY-TN00": "Huawei nova 7 SE",
    "CDY-N29H": "Huawei nova 7 SE",
    "CDY-N29B": "Huawei nova 7 SE",
    "CDY-N29": "Huawei nova 7 SE",
    "CDY-AN95": "Huawei nova 7 SE",
    "CDY-AN90": "Honor 30S",
    "CDY-AN20": "Huawei nova 7 SE",
    "CDY-AN00": "Huawei nova 7 SE",
    "CDL-AN50": "Huawei nova 7 SE",
    "CAZ-TL20": "Huawei Nova",
    "CAZ-TL10": "Huawei Nova",
    "CAZ-AL10": "Huawei Nova",
    "Cannes-L12": "Huawei Nova",
    "Cannes-L11": "Huawei Nova",
    "Cannes-L01": "Huawei Nova",
    "Cannes-AL10": "Huawei Nova Cannes-AL10",
    "CAN-L13": "Huawei Nova",
    "CAN-L12": "Huawei Nova",
    "CAN-L11": "Huawei nova",
    "CAN-L03": "Huawei Nova",
    "CAN-L01": "Huawei Nova",
    "Cameron-W19": "Huawei MediaPad M5 Pro 10.8",
    "CAM-UL00": "Huawei Honor 5A",
    "CAM-TL00": "Huawei Honor 5A",
    "CAM-L23": "Huawei Y6 II",
    "CAM-L21": "Huawei Y6 II",
    "CAM-L03": "Huawei Y6 II Compact",
    "CAM-AL00": "Huawei Honor 5A",
    "CairoGO-L22": "Huawei CairoGO-L22",
    "CairoGO-L02": "Huawei Y3 2018",
    "Cairo-U00": "Huawei Cairo-U00",
    "Cairo-L23": "Huawei Cairo-L23",
    "Cairo-L22": "Huawei Cairo-L22",
    "Cairo-L03": "Huawei Cairo-L03",
    "Cairo-L02": "Huawei Cairo-L02",
    "CAG-L02": "Huawei Y3 2018",
    "C8860V": "Huawei Honor",
    "C8817E": "Huawei C8817E",
    "C8817D": "Huawei Honor 6 Pro",
    "C8816D": "Huawei C8816D",
    "C8816": "Huawei C8816",
    "C199s": "Huawei C199S",
    "BZT3-W59": "Huawei C5 10.4",
    "BZT3-W09": "",
    "BZT3-AL00": "Honor 5c",
    "BZT-W09": "Huawei MediaPad C5 10.1",
    "BZD-W00": "Huawei MediaPad C3",
    "BZD-AL00": "Huawei MediaPad C3",
    "BZC-W00": "",
    "BZC-AL00": "",
    "BTV-W09": "Huawei M3",
    "BTV-DL09": "Huawei MediaPad M3",
    "BRQ-AN00CG": "Huawei nova 8 Pro 4G",
    "BRQ-AN00": "Huawei nova 8 Pro 5G",
    "BRQ-AL00": "Huawei nova 8 Pro 5G",
    "Bond-L24": "Huawei Honor 7X",
    "BOND-L21": "Huawei Honor 7X",
    "BND-TL10": "Huawei Honor 7X",
    "BND-L34": "Huawei Mate SE",
    "BND-L31A": "Huawei Honor 7X",
    "BND-L31": "Huawei Honor 7X",
    "BND-L24A": "Huawei Honor 7x",
    "BND-L21": "Huawei Honor 7X",
    "BND-AL10": "Huawei Honor 7X",
    "BND-AL00": "Huawei Honor 7X",
    "BMH-TN10": "Honor 30",
    "BMH-N19": "Honor 30",
    "BMH-AN20": "Honor 30",
    "BMH-AN10": "Honor 30",
    "BLN-TL10": "Huawei Honor 6X",
    "BLN-TL00": "Huawei Honor 6X",
    "BLN-L24": "Huawei Honor 6X",
    "BLN-L22HN": "Huawei Honor 6X",
    "BLN-L22": "Huawei Honor 6X",
    "BLN-L21": "Huawei Honor 6X",
    "BLN-AL40": "Huawei Honor 6X",
    "BLN-AL30": "Huawei Honor 6X",
    "BLN-AL20": "Huawei Honor 6X",
    "BLN-AL10": "Huawei Honor 6X",
    "BLL-L23": "Huawei Mate 9 Lite",
    "BLL-L22": "Huawei GR5 2017",
    "BLL-L21": "Huawei GR5 2017",
    "BLA-TL00": "Huawei Mate 10 Pro",
    "BLA-L29": "Huawei Mate 10 Pro",
    "BLA-L09": "Huawei Mate 10 pro",
    "BLA-AL00": "Huawei Mate 10 pro",
    "BLA-A09": "Huawei Mate 10 pro",
    "BKL-TL10": "Huawei Honor View 10",
    "BKL-L09": "Huawei Honor View 10 Global",
    "BKL-L04": "Huawei Honor View 10",
    "BKL-AL20": "Huawei Honor V10",
    "BKL-AL00": "Huawei Honor V10",
    "BKK-TL00": "Huawei Honor 8C",
    "BKK-L22": "Huawei Honor 8C",
    "BKK-L21": "Huawei Honor 8C",
    "BKK-AL10": "Huawei Honor 8C",
    "BKK-AL00": "Honor 8C",
    "BGO-L03": "Huawei MediaPad T2 7.0",
    "BGO-DL09": "Huawei MediaPad T2 7.0",
    "BG2-W09": "Huawei MediaPad T3",
    "BG2-U03": "Huawei MediaPad T3",
    "BG2-U01": "Huawei MediaPad T3 7 3G",
    "Berlin-L23": "Huawei Honor 6X",
    "Berlin-L22": "Huawei GR5 2017",
    "Berlin-L21HN": "Huawei Honor 6X",
    "Berlin-L21": "Huawei Honor 6X",
    "Berkeley-LGRP2": "Huawei Honor V10",
    "Barca-L22": "Huawei Barca-L22",
    "Barca-L21": "Huawei Nova 2 Plus",
    "Barca-L03": "Huawei Nova 2 Plus",
    "BAH3-W59": "Huawei MatePad 10.4",
    "BAH3-W09": "Huawei MatePad 10.4",
    "BAH3-L09": "Huawei MatePad 10.4",
    "BAH3-AN10": "Huawei MatePad 5G",
    "BAH3-AL00": "Huawei MatePad 10.4",
    "BAH2-W19": "Huawei MediaPad M5 lite",
    "BAH2-W09": "Huawei MediaPad M5 lite",
    "BAH2-L09": "Huawei MediaPad M5 Lite",
    "BAH2-AL10": "Huawei MediaPad M5 lite",
    "BAH-W09": "Huawei M3 Lite",
    "BAH-L09": "Huawei MediaPad M3 Lite 10",
    "BAH-AL00": "Huawei M3 Lite",
    "BAC-TL00": "Huawei nova 2 plus",
    "BAC-L23": "Huawei nova 2 plus",
    "BAC-L22": "Huawei nova 2 plus",
    "BAC-L21": "Huawei nova 2 plus",
    "BAC-L03": "Huawei nova 2 plus",
    "BAC-AL00": "Huawei Nova 2 Plus",
    "AUM-L41": "Huawei Honor 7C (Enjoy 8)",
    "AUM-L29": "Huawei Honor 7A Pro",
    "ATU-LX3": "Huawei Y6 2018",
    "ATU-L42": "Huawei Y6 Prime 2018",
    "ATU-L22": "Huawei Y6 2018",
    "ATU-L21": "Huawei Y6 2018",
    "ATU-L11": "Huawei Y6 2018",
    "ATU-L03": "Huawei Y6 2018",
    "ATU-AL10": "Huawei Enjoy 8e",
    "Atomu-L21": "Huawei Y6 Prime 2018",
    "Atomu-L03": "Huawei Honor 7A",
    "Atomu-AL20IND": "Huawei Honor 7A",
    "ATH-UL06": "Huawei ShotX",
    "ATH-UL01": "Huawei ShotX",
    "ATH-UL00": "Huawei Honor 7i",
    "ATH-TL00": "Huawei Honor 7i",
    "ATH-CL00": "Huawei Honor 7i",
    "ATH-AL00": "Huawei Honor 7i",
    "ASKH-TL00": "Honor Play 3",
    "ASKH-AL00": "Honor Play 3",
    "ARTH-TL00": "Huawei Enjoy 10",
    "ARTH-L29N": "Huawei Y7p",
    "ARTH-L29": "Huawei Y7p",
    "ARTH-L28": "Huawei Y7p",
    "ARTH-L09": "Huawei Enjoy 10",
    "ARTH-L08": "Huawei Enjoy 10",
    "ARTH-AL00M": "Huawei Enjoy 10",
    "ARTH-AL00": "Huawei Enjoy 10",
    "ARS-TL00": "Huawei Enjoy 9 Max",
    "ARS-L22": "Huawei Y Max",
    "Ares-L22HW": "Huawei Y Max",
    "ARE-TL00": "Huawei Honor 8X Max",
    "ARE-L22HN": "Huawei Honor 8X Max",
    "AQM-TL00": "Huawei Enjoy 10s",
    "AQM-L21A": "Huawei Y8P",
    "AQM-L01": "Huawei Y8p",
    "AQM-AL10HN": "Honor Play 4T Pro",
    "AQM-AL00": "Huawei Enjoy 10s",
    "ANG-AN00": "Huawei nova 8 5G",
    "ANE-TL00": "Huawei P20 lite",
    "ANE-LX3": "Huawei P20 Lite",
    "ANE-LX2JOT": "Huawei P20 Lite",
    "ANE-LX2J": "Huawei P20 Lite",
    "ANE-LX2": "Huawei Nova 3e",
    "ANE-LX1": "Huawei P20 Lite",
    "ANE-LGRP1": "Huawei P20 Lite",
    "ANE-L21": "Huawei P20 Lite",
    "ANE-L12JPZ": "Huawei Nova 3e",
    "ANE-L12": "Huawei Nova 3e",
    "ANE-L03": "Huawei Nova 3e",
    "ANE-L02J": "Huawei Nova 3e",
    "ANE-L02": "Huawei Nova 3e",
    "ANE-AL00I": "Huawei P20 Lite",
    "ANE-AL00": "Huawei P20 Lite",
    "ANA-TN00": "Huawei P40",
    "ANA-N29": "Huawei P40",
    "ANA-L04": "Huawei P40",
    "ANA-AN00": "Huawei P40",
    "ANA-AL00": "Huawei P40 4G",
    "AMN-L29": "Huawei Y5 (2019)",
    "AMN-L22": "Huawei Y5 (2019)",
    "AMN-L09": "Huawei Y5 (2019)",
    "ALP-TL00ZZB51": "Huawei Mate 10",
    "ALP-TL00B": "Huawei Mate 10",
    "ALP-TL00": "Huawei Mate 10",
    "ALP-LGRP2": "Huawei Mate 10",
    "ALP-LGRP1": "Huawei Mate 10",
    "ALP-L29": "Huawei Mate 10",
    "ALP-L09": "Huawei Mate 10",
    "ALP-AL00ZZB54": "Huawei Mate 10",
    "ALP-AL00ZZB02": "Huawei Mate 10",
    "ALP-AL00": "Huawei Mate 10",
    "ALE-TL00": "Huawei P8 Lite",
    "ALE-L32": "Huawei P8 Lite",
    "ALE-L23URY": "Huawei P8 Lite",
    "ALE-L23": "Huawei P8 Lite",
    "ALE-L21TUR": "Huawei P8 Lite",
    "ALE-L21S": "Huawei P8 Lite",
    "ALE-L21POL": "Huawei P8 Lite",
    "ALE-L21MKD": "Huawei P8 Lite",
    "ALE-L21HUN": "Huawei P8 Lite",
    "ALE-L21HR": "Huawei P8 Lite",
    "ALE-L21GR": "Huawei P8 Lite",
    "ALE-L21FRA": "Huawei P8 Lite",
    "ALE-L21DEU": "Huawei P8 Lite",
    "ALE-L21AUT": "Huawei P8 Lite",
    "ALE-L21": "Huawei P8 Lite",
    "ALE-L03": "Huawei P8 Lite",
    "ALE-L02": "Huawei P8 Lite",
    "ALE-L01": "Huawei P8 Lite",
    "ALE-CL00": "Huawei P8 Lite",
    "AKA-L29": "Honor Play 4T",
    "AKA-AL20": "Honor Play 4T",
    "AKA-AL10": "Honor Play 4T",
    "AGS3K-W10": "Huawei MatePad T 10s",
    "AGS3K-W09": "Huawei MatePad T 10s",
    "AGS3K-L09": "Huawei MatePad T 10s",
    "AGS3-W09HN": "Huawei Enjoy Tablet 2",
    "AGS3-W09": "Huawei MatePad T 10s",
    "AGS3-W00E": "Huawei Enjoy Tablet 2",
    "AGS3-W00D": "Huawei Enjoy Tablet 2",
    "AGS3-W00B": "Huawei Enjoy Tablet 2",
    "AGS3-L09": "Huawei MatePad T 10s",
    "AGS3-AL09HN": "Huawei Enjoy Tablet 2",
    "AGS3-AL00": "Huawei Enjoy Tablet 2",
    "AGS2-W09HN": "Huawei MediaPad T5",
    "AGS2-W09AUS": "Huawei MediaPad T5",
    "AGS2-W09": "Huawei MediaPad T5",
    "AGS2-L09": "Huawei MediaPad T5",
    "AGS2-L03": "Huawei MediaPad T5",
    "AGS2-AL00HN": "Huawei MediaPad T5",
    "AGS2-AL00": "Honor Pad 5 10.1",
    "AGS-W09": "Huawei MediaPad T3 10",
    "AGS-L09": "Huawei MediaPad T3 10",
    "AGRK-W09K": "Huawei MatePad T 10s",
    "AGRK-W09": "Huawei AGRK-W09",
    "AGRK-L09K": "Huawei MatePad T 10s",
    "AGRK-L09": "Huawei MatePad T 10s",
    "AGR-W09K": "Honor Pad X6",
    "AGR-W09HN": "Huawei Enjoy Tablet 2",
    "AGR-W09": "Honor Pad X6",
    "AGR-L09": "Huawei MatePad T 10s",
    "AGR-AL09HN": "Honor Pad X6",
    "7D-504L": "Huawei MediaPad X1 7.0",
    "7D-501u": "Huawei MediaPad X1 7.0",
    "7D-501L": "Huawei MediaPad X1 7.0",
    "704HW": "Huawei Nova Lite 2",
    "608HW": "Huawei nova lite",
    "NOP-AN01P": "Huawei Mate 40 Pro+",
    "NOP-AN00P": "Huawei Mate 40 Pro+",
    "NOP-AN00": "Huawei Mate 40 Pro+",
    "NOH-N29": "Huawei Mate 40 Pro",
    "NOH-AN01": "Huawei Mate 40 Pro",
    "NOH-AN00": "Huawei Mate 40 Pro",
    "NMO-L31": "Huawei GT3",
    "NMO-L22": "Huawei GT3",
    "NMO-L02": "Huawei NMO-L02",
    "NICE-TL10": "Huawei Nice-TL10",
    "NICE-AL10": "Huawei Nice-AL10",
    "NICE-AL00": "Huawei Nice-AL00",
    "NEO-L29": "Huawei Mate RS",
    "NEN-L23CQ": "Huawei nova 8 5G",
    "NEN-L22CQ": "Huawei nova 8 5G",
    "NEN-L21CQ": "Huawei nova 8 5G",
    "NEN-L03CQ": "Huawei nova 8 5G",
    "NEN-L01CQ": "Huawei nova 8 5G",
    "NEM-UL10": "Huawei Honor 5C",
    "NEM-TL00": "Huawei Honor 5C",
    "NEM-L51": "Huawei Honor 5C",
    "NEM-L22": "Huawei Honor 5C",
    "NEM-L21": "Huawei HONOR 7 Lite",
    "NEM-AL10": "Huawei Honor 5C",
    "MXWM-TN00": "Honor 30 Youth",
    "MXWM-AN00": "Honor 30 Youth",
    "MT7-UL00": "Huawei Ascend Mate 7",
    "MT7-TL10": "Huawei Ascend Mate7",
    "MT7-TL00": "Huawei Mate 7",
    "MT7-L11": "Huawei Ascend Mate7",
    "MT7-L09": "Huawei Ascend Mate7",
    "MT7-J1": "Huawei Ascend Mate 7",
    "MT7-CL00": "Huawei Ascend Mate 7",
    "MT2-L05": "Huawei Ascend Mate2",
    "MT1-U06": "Huawei Ascend Mate7",
    "MT-L09": "Huawei Ascend Mate7",
    "MRX-W39": "Huawei MatePad Pro",
    "MRX-W29": "Huawei MatePad Pro",
    "MRX-W19": "Huawei MatePad Pro",
    "MRX-W09": "Huawei MatePad Pro",
    "MRX-AN19": "Huawei MatePad Pro 5G",
    "MRX-AL19": "Huawei MatePad Pro",
    "MRX-AL09": "Huawei MatePad Pro",
    "MRD-TL00": "Huawei Enjoy 9e",
    "MRD-LX3": "Huawei Y6 2019",
    "MRD-L41A": "Huawei Y6 (2019)",
    "MRD-L41": "Huawei Y6 2019",
    "MRD-L23": "Huawei Y6 2019",
    "MRD-L22": "Huawei Y6 Pro (2019)",
    "MRD-L21A": "Huawei Y6 Pro (2019)",
    "MRD-L21": "Huawei Y6 2019",
    "MRD-L11": "Huawei Y6 2019",
    "MRD-L01": "Huawei Y6 2019",
    "MRD-AL00": "Huawei Enjoy 9e",
    "MOA-TL00": "Honor Play 9A",
    "MOA-L49I": "Honor Play 9A",
    "MOA-L49": "Honor 9A",
    "MOA-AL20": "Honor Play 9A",
    "MOA-AL00": "Honor Play 9A",
    "MLA-UL00": "Huawei G9 Plus",
    "MLA-TL10": "Huawei G9 Plus",
    "MLA-TL00": "Huawei G9 Plus",
    "MLA-L13": "Huawei nova plus",
    "MLA-L12": "Huawei nova plus",
    "MLA-L11": "Huawei nova plus",
    "MLA-L03": "Huawei Nova plus",
    "MLA-L02": "Huawei Nova Plus",
    "MLA-L01": "Huawei Nova Plus",
    "MLA-AL10": "Huawei Nova Plus",
    "MLA-AL00": "Huawei Maimang 5",
    "MHA-TL00": "Huawei Mate 9",
    "MHA-L29": "Huawei Mate 9",
    "MHA-L09": "Huawei Mate 9",
    "MHA-AL00": "Huawei Mate 9 Pro",
    "MED-TL00": "Huawei Enjoy 10",
    "MED-L49": "Huawei Y6p",
    "MED-L29II": "Honor 9A",
    "MED-L29": "Honor 9A",
    "MED-L09": "Huawei Y6p",
    "MED-AL20": "Honor Play 9A",
    "MED-AL10": "Honor Play 9A",
    "MED-AL00": "Honor Play 9A",
    "Maya-U29": "Huawei Honor Maya",
    "Maya-TL10": "Huawei Honor Maya",
    "Maya-L41": "Huawei Y6 2017",
    "Maya-L13": "Huawei Honor Maya",
    "Maya-L11": "Huawei Y6 2017",
    "Maya-L03": "Huawei Maya L03",
    "Maya-AL10": "Huawei Honor Maya",
    "MAR-TL00": "Huawei nova 4e",
    "MAR-L22BX": "Huawei P30 lite",
    "MAR-L22B": "Huawei P30 lite",
    "MAR-L22A": "Huawei P30 lite",
    "MAR-L21MEB": "Huawei P30 lite",
    "MAR-L21MEA": "Huawei P30 lite",
    "MAR-L21H": "Huawei P30 lite",
    "MAR-L21B": "Huawei P30 lite",
    "MAR-L21A": "Huawei P30 lite",
    "MAR-L03A": "Huawei P30 lite",
    "MAR-L01MEB": "Huawei P30 lite",

    # redmi and Mi and POCO devices
    '2014215': 'Xiaomi Mi 4',
    '2014712': 'Xiaomi Redmi Note',
    '2014817': 'Xiaomi Redmi 2',
    '2014818': 'Xiaomi Redmi 2',
    '2015015': 'Xiaomi Mi 4i',
    '2015051': 'Xiaomi Redmi Note 2',
    '2015105': 'Xiaomi Mi 5',
    '2015116': 'Xiaomi Redmi Note 3',
    '2015161': 'Xiaomi Redmi Note 3',
    '2015213': 'Xiaomi Mi Note 2',
    '2015711': 'Xiaomi Mi 5s',
    '2015816': 'Xiaomi Redmi 3',
    '2016001': 'Xiaomi Mi Max',
    '2016002': 'Xiaomi Mi Max',
    '2016007': 'Xiaomi Mi Max',
    '2016031': 'Xiaomi Redmi 3s',
    '2016060': 'Xiaomi Redmi 4 (4X)',
    '2016070': 'Xiaomi Mi 5s Plus',
    '2016090': 'Xiaomi Redmi 4 (4X)',
    '2016100': 'Xiaomi Redmi Note 4',
    '2016117': 'Xiaomi Redmi 4A',
    'AWM-A0': 'Xiaomi Black Shark Helo',
    'DLT-A0': 'Xiaomi Black Shark 2 Pro',
    'DLT-H0': 'Xiaomi Black Shark 2 Pro',
    'M1803D5XA': 'Xiaomi Mi Mix 2S',
    'M1803E1A': 'Xiaomi Mi 8',
    'M1803E6G': 'Xiaomi Redmi S2 (Redmi Y2)',
    'M1803E6H': 'Xiaomi Redmi S2 (Redmi Y2)',
    'M1803E6I': 'Xiaomi Redmi S2 (Redmi Y2)',
    'M1803E7SG': 'Xiaomi Redmi Note 5 AI Dual Camera',
    'M1803E7SH': 'Xiaomi Redmi Note 5 AI Dual Camera',
    'M1804C3CG': 'Xiaomi Redmi 6A',
    'M1804C3CH': 'Xiaomi Redmi 6A',
    'M1804C3CI': 'Xiaomi Redmi 6A',
    'M1804C3DG': 'Xiaomi Redmi 6',
    'M1804C3DH': 'Xiaomi Redmi 6',
    'M1804C3DI;': 'Xiaomi Redmi 6',
    'M1804D2SG': 'Xiaomi Mi A2 (Mi 6X)',
    'M1804D2SI': 'Xiaomi Mi A2 (Mi 6X)',
    'M1804E4A': 'Xiaomi Mi Max 3',
    'M1805D1SG': 'Xiaomi Mi A2 Lite (Redmi 6 Pro)',
    'M1805E10A': 'Xiaomi Pocophone F1',
    'M1806E7TG': 'Xiaomi Redmi Note 6 Pro',
    'M1806E7TH': 'Xiaomi Redmi Note 6 Pro',
    'M1806E7TI': 'Xiaomi Redmi Note 6 Pro',
    'M1807E8A': 'Xiaomi Mi 8 Pro',
    'M1808D2TG': 'Xiaomi Mi 8 Lite',
    'M1810F6LG': 'Xiaomi Redmi 7',
    'M1810F6LH': 'Xiaomi Redmi 7',
    'M1810F6LI': 'Xiaomi Redmi 7',
    'M1901F71': 'Xiaomi Redmi Note 7S',
    'M1901F7G': 'Xiaomi Redmi Note 7',
    'M1901F7H': 'Xiaomi Redmi Note 7',
    'M1901F7I': 'Xiaomi Redmi Note 7',
    'M1901F7S': 'Xiaomi Redmi Note 7 Pro',
    'M1901F9E': 'Xiaomi Mi Play',
    'M1902F1G': 'Xiaomi Mi 9',
    'M1903C3EG': 'Xiaomi Redmi 7A',
    'M1903C3EH': 'Xiaomi Redmi 7A',
    'M1903C3EI': 'Xiaomi Redmi 7A',
    'M1903C3GG': 'Xiaomi Redmi Go',
    'M1903C3GH': 'Xiaomi Redmi Go',
    'M1903C3GI': 'Xiaomi Redmi Go',
    'M1903F10G': 'Xiaomi Mi 9T',
    'M1903F10I': 'Xiaomi Redmi K20',
    'M1903F11G': 'Xiaomi Mi 9T Pro',
    'M1903F2G': 'Xiaomi Mi 9 SE',
    'M1904F3BG': 'Xiaomi Mi 9 Lite',
    'M1906F9SH': 'Xiaomi Mi A3',
    'M1906F9SI': 'Xiaomi Mi A3',
    'M1906G7G': 'Xiaomi Redmi Note 8 Pro',
    'M1906G7I': 'Xiaomi Redmi Note 8 Pro',
    'M1908C3JG': 'Xiaomi Redmi Note 8',
    'M1908C3JH': 'Xiaomi Redmi Note 8',
    'M1908C3JI': 'Xiaomi Redmi Note 8',
    'M1908C3KG': 'Xiaomi Redmi 8A',
    'M1908C3KH': 'Xiaomi Redmi 8A',
    'M1908C3XG': 'Xiaomi Redmi Note 8T',
    'M1910F4E': 'Xiaomi Mi CC9 Pro',
    'M1910F4G': 'Xiaomi Mi Note 10 Lite',
    'M1910F4S': 'Xiaomi Mi Note 10 Pro',
    'M1912G7BC': 'Xiaomi Redmi K30',
    'M1912G7BE': 'Xiaomi Redmi K30',
    'M2001C3K3I': 'Xiaomi Redmi 8A Dual',
    'M2001J1G': 'Xiaomi Mi 10 Pro 5G',
    'M2001J2G': 'Xiaomi Mi 10 5G',
    'M2001J2I': 'Xiaomi Mi 10 5G',
    'M2002F4LG': 'Xiaomi Mi Note 10 Lite',
    'M2002J9E': 'Xiaomi Mi 10 Youth 5G',
    'M2002J9G': 'Xiaomi Mi 10 Lite 5G',
    'M2003J15SC': 'Xiaomi Redmi 10X 4G',
    'M2003J15SG': 'Xiaomi Redmi Note 9',
    'M2003J15SS': 'Xiaomi Redmi Note 9',
    'M2003J6A1G': 'Xiaomi Redmi Note 9S',
    'M2003J6A1I': 'Xiaomi Redmi Note 9 Pro (India)',
    'M2003J6B1I': 'Xiaomi Redmi Note 9 Pro Max',
    'M2004C3MI': 'Xiaomi Redmi 9 (India)',
    'M2004J11G': 'Xiaomi Poco F2 Pro',
    'M2004J19C': 'Xiaomi Redmi 9',
    'M2004J19G': 'Xiaomi Redmi 9',
    'M2010J19SI': 'Xiaomi Redmi 9 Power',
    'M2004J19PI': 'Xiaomi Poco M2',
    'M2004J7AC': 'Xiaomi Redmi Note 10',
    'M2101K6I': 'Xiaomi Redmi Note 10 Pro Max',
    'M2103K19G': 'Xiaomi Redmi Note 10 5G',
    'M2004J7BC': 'Xiaomi Redmi 10X Pro 5G',
    'M2006C3LC': 'Xiaomi Redmi 9A',
    'M2006C3LG': 'Xiaomi Redmi 9A',
    'M2006C3LI': 'Xiaomi Redmi 9A',
    'M2006C3LII': 'Xiaomi Redmi 9i',
    'M2006C3LVG': 'Xiaomi Redmi 9AT',
    'M2006C3MG': 'Xiaomi Redmi 9C',
    'M2006C3MII': 'Xiaomi Redmi 9 (India)',
    'M2006C3MNG': 'Xiaomi Redmi 9C NFC',
    'M2006J10C': 'Xiaomi Redmi K30 Ultra',
    'M2007J17C': 'Xiaomi Redmi Note 9 Pro 5G',
    'M2007J17G': 'Xiaomi Mi 10T Lite 5G',
    'M2007J17I': 'Xiaomi Mi 10i',
    'M2007J1SC': 'Xiaomi Mi 10 Ultra',
    'M2007J20CG': 'Xiaomi Poco X3 NFC',
    'M2007J20CI': 'Xiaomi Poco X3',
    'M2007J20CT': 'Xiaomi Poco X3 NFC',
    'M2007J22C': 'Xiaomi Redmi Note 9 5G',
    'M2007J3SC': 'Xiaomi Redmi K30S',
    'M2007J3SG': 'Xiaomi Mi 10T Pro 5G',
    'M2007J3SY': 'Xiaomi Mi 10T 5G',
    'M2010J19CG': 'Xiaomi Poco M3',
    'M2010J19CI': 'Xiaomi Poco M3',
    'MAE136': 'Xiaomi Redmi 4 (4X)',
    'MAG138': 'Xiaomi Redmi 4 (4X)',
    'MCE16': 'Xiaomi Mi 6',
    'MCE8': 'Xiaomi Mi Note 3',
    'MCG3B': 'Xiaomi Redmi 5A',
    'MCI3B': 'Xiaomi Redmi 5A',
    'MDE40': 'Xiaomi Mi Max 2',
    'MDE5': 'Xiaomi Mi Mix 2',
    'MDG1': 'Xiaomi Redmi 5',
    'MDG2': 'Xiaomi Mi A1 (Mi 5X)',
    'MDI1': 'Xiaomi Redmi 5',
    'MDI2': 'Xiaomi Mi A1 (Mi 5X)',
    'MDI40': 'Xiaomi Mi Max 2',
    'MDI6': 'Xiaomi Redmi Y1 Lite',
    'MDI6S': 'Xiaomi Redmi Y1 (Note 5A)',
    'MEG7': 'Xiaomi Redmi 5 Plus (Redmi Note 5)',
    'MEI7': 'Xiaomi Redmi Note 5 Pro',
    'MEI7S': 'Xiaomi Redmi Note 5 Pro',
    'MZB07QAIN': 'Xiaomi Poco C3',
    'MZB07RHIN': 'Xiaomi Poco C3',
    'MZB07RIIN': 'Xiaomi Poco C3',
    'MZB07RJIN': 'Xiaomi Poco C3',
    'MZB07RKIN': 'Xiaomi Poco C3',
    'MZB07RLIN': 'Xiaomi Poco C3',
    'MZB07Z0IN': 'Xiaomi Poco X3',
    'MZB07Z1IN': 'Xiaomi Poco X3',
    'MZB07Z2IN': 'Xiaomi Poco X3',
    'MZB07Z3IN': 'Xiaomi Poco X3',
    'MZB07Z4IN': 'Xiaomi Poco X3',
    'MZB7995IN': 'Xiaomi Redmi 7A',
    'MZB8458IN': 'Xiaomi Redmi 8A',
    'MZB8741IN': 'Xiaomi Poco X2',
    'MZB8742IN': 'Xiaomi Poco X2',
    'MZB8743IN': 'Xiaomi Poco X2',
    'MZB8744IN': 'Xiaomi Poco X2',
    'MZB8745IN': 'Xiaomi Poco X2',
    'MZB8746IN': 'Xiaomi Poco X2',
    'MZB9011IN': 'Xiaomi Poco X2',
    'MZB9012IN': 'Xiaomi Poco X2',
    'MZB9013IN': 'Xiaomi Poco X2',
    'MZB9919IN': 'Xiaomi Poco M2',
    'MZB9965IN': 'Xiaomi Poco X3',
    'SHARK MBU-A0': 'Xiaomi Black Shark 3 Pro',

    'SHARK MBU-H0': 'Xiaomi Black Shark 3 Pro',
    'SKW-A0': 'Xiaomi Black Shark 2',
    'SKW-H0': 'Xiaomi Black Shark 2',

    # Realme devices
    "RMX1931": "Realme X",
    "RMX1901": "Realme X",
    "RMX1941": "Realme C2",
    "RMX2156": "Realme Narzo 30",
    "RMX3360": "Realme GT Master Edition",
    "RMX1851": "Realme 3 Pro",
    "RMX2030": "Realme 5i",

    #     BlackBerry devices
    "BBG100-1": "BlackBerry Evolve",

    # Asus
    "ASUS_X00TD": "ASUS Zenfone Max Pro M1",
    "ASUS_Z017DB": "ASUS Zenfone 3",
    "ASUS_X00HD": "Asus Zenfone 4 Max",
    "ASUS_X00TDA": "ASUS Zenfone Max Pro M1",
    "ASUS_I01WD": "Asus Zenfone 6",
    "ASUS_Z01RD": "Asus Zenfone 5Z",
    "ZS630KL": "Asus Zenfone 6",
    "I01WD": "Asus Zenfone 6",
    # LG device
    "LG-V700": "LG G Pad 10.1",
    "LG-US996": "LG V20",
    #     Others
    "V2037": "vivo Y20G",
    "I2012": "vivo"
}
